// @flow
import theme from 'shared/theme';
import React from 'react';
import styled from 'styled-components';
import { zIndex } from '../globals';

export const Cluster = styled.img`
  position: absolute;
  opacity: 0.05;
`;

export const ClusterOne = styled(Cluster)`
  max-width: 120px;
  max-height: 120px;
  top: 10%;
  left: 10%;
  z-index: ${zIndex.background};
`;

export const ClusterTwo = styled(Cluster)`
  max-width: 160px;
  max-height: 160px;
  top: 60%;
  right: 10%;
  z-index: ${zIndex.background};
`;

export const ClusterThree = styled(Cluster)`
  max-width: 80px;
  max-height: 80px;
  top: 10%;
  right: 40%;
  z-index: ${zIndex.background};
`;

export const ClusterFour = styled(Cluster)`
  max-width: 80px;
  max-height: 80px;
  top: 80%;
  left: 40%;
  z-index: ${zIndex.background};
`;

export const Constellations = styled.div`
  position: absolute;
  background-color: transparent;
  background: url('/img/constellations.svg') center top no-repeat;
  background-size: cover 100%;
  z-index: ${zIndex.background};
  height: calc(100% + 4px);
  width: 110%;
  top: -10px;
  bottom: 0;
  left: 0;
  right: 0;
  pointer-events: none;
`;

export const ConversationWrapper = styled.div`
  position: relative;
  z-index: ${zIndex.background};

  max-width: 480px;
  overflow-y: hidden;
  box-shadow: 0 0 32px 24px ${theme.bg.default};
  display: inline-block;
  align-items: center;
  justify-content: center;

  @media (max-width: 768px) {
    display: none;
  }

  > img {
    height: 100%;
    width: 100%;
    object-fit: contain;
    pointer-events: none;
  }

  + div {
    margin-left: 48px;

    @media (max-width: 768px) {
      margin-left: 0;
      margin-bottom: 32px;
    }
  }
`;

export const Conversation = () => (
  <ConversationWrapper>
    <img src="/img/conversation.svg" alt="conversation screenshot" />
  </ConversationWrapper>
);

const DiscoverImage = styled.img`
  position: relative;
  left: -24px;
  max-width: 400px;
  height: auto;
  object-fit: contain;

  @media (max-width: 768px) {
    left: auto;
    margin-top: 32px;
    max-width: 100%;
    min-width: 256px;
  }
`;

export const Discover = () => <DiscoverImage src="/img/discover.png" alt="" />;

const EmptyImage = styled.img`
  position: absolute;
  right: -10%;
  top: 5%;
  bottom: -10%;
  height: 120%;
  z-index: ${zIndex.background};
`;

export const Empty = () => <EmptyImage src="/img/empty.svg" alt="" />;

const InlineSvg = styled.svg`
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  height: 100%;
  width: 100%;
  color: inherit;
  fill: currentColor;
`;

const SvgWrapper = styled.div`
  display: inline-block;
  position: relative;
  grid-area: topic;
  justify-self: flex-start;
  min-height: 200px;
  min-width: 300px;
  height: 100%;
  width: 100%;
`;

export const Easy = () => (
  <SvgWrapper>
    <InlineSvg
      fillRule="evenodd"
      clipRule="evenodd"
      strokeLinejoin="round"
      strokeMiterlimit="1.414"
      xmlns="http://www.w3.org/2000/svg"
      aria-labelledby="title"
      viewBox="0 0 630 463"
      preserveAspectRatio="xMidYMid meet"
      fit
      id={'easy'}
    >
      <title id="title">{'easy'}</title>
      <g id="Canvas" fill="none">
        <g id="easy">
          <mask
            id="mask0"
            mask-type="alpha"
            maskUnits="userSpaceOnUse"
            x="-9"
            y="-11"
            width="639"
            height="474"
          >
            <path
              id="Union"
              fillRule="evenodd"
              clipRule="evenodd"
              d="M 629.188 0L 153.38 0L 153.283 155.41C 69.1314 205.422 -32.9109 357.603 10.2302 432.353C 47.7807 497.416 118.01 483.561 233.797 409.489L 639 469.574L 629.188 0Z"
              transform="translate(630 -11) scale(-1 1)"
              fill="#C4C4C4"
            />
          </mask>
          <g mask="url(#mask0)">
            <path
              id="Ellipse 2.4"
              d="M 10.2302 291.569C -33.2406 216.247 70.6996 62.3076 155.21 13.4975C 239.72 -35.3125 163.58 67.7898 365.398 17.7448C 567.216 -32.3002 443.055 122.055 292.011 229.251C 140.968 336.446 53.701 366.891 10.2302 291.569Z"
              transform="translate(630 129.784) scale(-1 1)"
              fill="white"
            />
            <g id="Group 5">
              <g id="Group 5_2">
                <g id="Group 5_3">
                  <path
                    id="Vector"
                    d="M 52.5254 0.0326982C 51.1383 0.680618 43.278 11.9729 33.9381 25.9495C 27.9273 34.9278 21.454 45.0169 15.7206 54.1803C 6.93557 68.2494 0.0924631 80.1896 -1.12884e-05 82.6887C -1.12884e-05 83.892 12.669 92.4075 30.1467 103.515C 38.5618 89.0754 70.0031 36.8716 82.7645 15.6753C 66.0267 6.0491 53.6351 -0.522662 52.5254 0.0326982Z"
                    transform="translate(458.837 0.533203) scale(-1 1)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_2"
                    d="M 55.2072 1.48097C 54.3749 1.01817 53.5427 0.4628 52.6179 0C 39.764 21.1962 8.32268 73.4 -1.12884e-05 87.8394C 0.647309 88.3022 1.29464 88.6724 2.03444 89.1352C 11.8367 95.3367 22.9336 102.279 34.2155 109.128C 44.3877 91.8195 76.1989 38.9677 87.3883 20.5483C 76.1989 13.7914 65.0095 7.21968 55.2072 1.48097Z"
                    transform="translate(428.783 16.116) scale(-1 1)"
                    fill="#A3AFBF"
                  />
                  <path
                    id="Vector_3"
                    d="M 56.3169 1.94375C 55.2997 1.29583 54.19 0.647917 53.1727 -2.82471e-06C 41.9833 18.512 10.1722 71.2712 -1.12884e-05 88.5799C 0.924732 89.1352 1.8495 89.6906 2.68177 90.246C 13.2238 96.6326 23.581 102.927 32.9209 108.48C 45.035 88.2096 73.887 41.3743 86.556 20.7334C 77.3086 14.8096 66.859 8.33039 56.3169 1.94375Z"
                    transform="translate(394.567 36.6643) scale(-1 1)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_4"
                    d="M 85.5388 23.3251C 85.0764 21.1962 73.887 13.1435 58.1664 2.86935C 56.6868 1.94375 55.2072 0.925611 53.6352 1.12988e-05C 40.9662 20.6409 12.2066 67.4762 2.25767e-05 87.7468C 1.66456 88.765 3.32909 89.6906 4.90115 90.6162C 21.2691 100.242 33.1058 106.999 33.8456 106.722C 34.7704 106.444 43.3705 94.3186 53.3577 79.3239C 59.3685 70.253 65.9342 60.164 71.4827 51.0005C 79.8054 37.3017 86.0937 25.9168 85.5388 23.3251Z"
                    transform="translate(361.647 57.4902) scale(-1 1)"
                    fill="#A3AFBF"
                  />
                  <path
                    id="Vector_5"
                    d="M -2.25767e-05 -5.64941e-06L 123.361 74.2331"
                    transform="translate(453.011 54.4358) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_6"
                    d="M -1.12884e-05 1.12988e-05L 31.4413 18.8822"
                    transform="translate(370.986 58.8787) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_7"
                    d="M 0 5.64941e-06L 42.9081 25.9168"
                    transform="translate(424.899 26.3904) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                </g>
                <g id="Group 5_4">
                  <path
                    id="Vector_8"
                    d="M 81.9323 19.8078C 81.9323 21.2888 75.5516 33.5067 67.3214 48.1312C 62.0503 57.5723 56.0394 67.939 50.491 77.2876C 41.9833 91.5418 34.493 103.112 32.2736 104.315C 31.2564 104.87 17.8476 97.4656 0 86.9138C 8.97001 72.9372 41.1511 21.1037 54.19 -5.64941e-06C 70.4654 10.5518 81.9323 18.6045 81.9323 19.8078Z"
                    transform="translate(82.744 228.448) scale(-1 1)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_9"
                    d="M 86.0936 19.9004C 86.9259 20.4558 87.7582 21.0111 88.5905 21.4739C 75.5516 42.5776 43.3704 94.3186 34.4004 108.388C 33.7531 108.017 33.0133 107.555 32.366 107.184C 22.3788 101.261 11.1894 94.5037 0 87.6543C 10.8195 70.7158 43.278 18.3269 54.6523 5.64941e-06C 65.6568 6.84944 76.5688 13.7914 86.0936 19.9004Z"
                    transform="translate(116.96 206.882) scale(-1 1)"
                    fill="#A3AFBF"
                  />
                  <path
                    id="Vector_10"
                    d="M 84.2441 18.512C 85.2613 19.1599 86.3711 19.8078 87.3883 20.4558C 76.0139 38.7826 43.5554 91.1716 32.7359 108.11C 31.8112 107.555 30.8864 106.999 30.0542 106.444C 19.6046 99.9648 9.24744 93.5781 0 87.7468C 12.484 67.6613 41.0586 20.7334 53.6351 0C 63.16 5.64616 73.702 11.9402 84.2441 18.512Z"
                    transform="translate(149.788 186.426) scale(-1 1)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_11"
                    d="M 50.7721 0.0340114C 52.899 -0.521348 65.198 5.77275 81.3811 15.2139C 82.8606 16.0469 84.4327 16.9725 86.0048 17.8981C 73.4283 38.6315 44.8537 85.5594 32.3696 105.645C 30.7051 104.627 29.1331 103.609 27.561 102.59C 11.563 92.4089 0.188563 84.9115 0.00361453 84.0785C -0.181334 83.0603 6.75429 69.9168 15.5394 54.2742C 20.9029 44.7405 26.9136 34.3738 32.4621 25.2103C 40.8773 11.604 48.1828 0.774491 50.7721 0.0340114Z"
                    transform="translate(182.158 168.621) scale(-1 1)"
                    fill="#A3AFBF"
                  />
                  <path
                    id="Vector_12"
                    d="M 61.7729 38.5049L 0 1.12988e-05"
                    transform="translate(115.11 259.734) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_13"
                    d="M 16.9228 10.5518L 2.25767e-05 -1.12988e-05"
                    transform="translate(44.4597 303.792) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_14"
                    d="M 55.4846 34.6174L -2.25767e-05 0"
                    transform="translate(124.265 208.641) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_15"
                    d="M 42.5382 26.5647L 2.25767e-05 1.12988e-05"
                    transform="translate(57.8685 250.015) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                </g>
                <path
                  id="Vector_16"
                  d="M 104.732 47.563C 103.807 38.1219 100.478 29.5138 95.3917 22.2942C 90.583 15.5373 84.2949 9.98368 76.9894 6.09616C 68.3893 1.56073 58.402 -0.660708 48.0449 0.172332C 47.8599 0.172332 47.675 0.172332 47.5825 0.172332C 30.3823 1.83841 15.9563 11.5572 7.63363 25.1635C 1.99269 34.5121 -0.874012 45.6193 0.23568 57.3744C 0.23568 57.6521 0.328132 57.8372 0.328132 58.1148C 1.62277 70.1476 6.98624 80.8846 14.8466 89.0299C 24.0015 98.471 36.6705 104.395 50.4492 104.95C 52.7611 105.043 55.0729 104.95 57.4772 104.765C 74.6775 103.099 89.1035 93.3802 97.4262 79.7739C 102.975 70.4253 105.841 59.2256 104.732 47.563Z"
                  transform="translate(281.522 113.78) scale(-1 1)"
                  fill="#1CD2F2"
                />
                <path
                  id="Union_2"
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M 71.0522 0.00113563C 72.1562 0.0377567 73.0213 0.962561 72.9846 2.06657C 72.6619 11.7541 70.0705 26.0592 60.2175 41.9132L 69.4667 47.5382L 95.5377 4.48136C 96.1098 3.53654 97.3395 3.23429 98.2844 3.80631C 99.2292 4.37858 99.5314 5.60831 98.9593 6.55314L 72.8843 49.6166L 86.3183 57.7863C 89.4051 51.7682 92.9311 46.3039 96.572 41.4357C 97.2335 40.5512 98.4868 40.3703 99.3714 41.0319C 100.256 41.6933 100.437 42.9467 99.7752 43.8312C 96.1939 48.6198 92.7448 53.9797 89.7446 59.87L 137.127 88.6857C 138.071 89.2597 138.371 90.4901 137.797 91.4338C 137.223 92.3776 135.993 92.6774 135.049 92.1034L 87.9924 63.486C 82.0167 76.4772 78.3649 91.8363 80.0967 109.17C 80.2066 110.269 79.4046 111.249 78.3055 111.359C 77.2064 111.469 76.2264 110.667 76.1166 109.568C 74.2823 91.2074 78.2194 75.0019 84.5534 61.3947L 70.8126 53.0382L 56.4211 76.8061C 55.8489 77.7511 54.6192 78.0531 53.6744 77.4811C 52.7294 76.9091 52.4273 75.6791 52.9994 74.7343L 67.395 50.9599L 58.0369 45.2687C 53.5483 51.8832 47.7678 58.7243 40.3464 65.5771C 39.5348 66.3263 38.2695 66.276 37.5202 65.4645C 36.7708 64.653 36.8212 63.3876 37.6327 62.6383C 44.7607 56.0566 50.3083 49.5053 54.6144 43.1872L 0.961119 10.558C 0.017271 9.98405 -0.282412 8.75382 0.291441 7.80997C 0.865416 6.86637 2.09576 6.56657 3.03949 7.14054L 56.7993 39.8344C 66.2735 24.6042 68.6854 10.9836 68.9868 1.93326C 69.0235 0.829505 69.9483 -0.0357296 71.0522 0.00113563ZM 144.157 92.9452C 143.215 92.3698 141.984 92.6679 141.409 93.6108C 140.833 94.5539 141.131 95.7846 142.074 96.3598L 165.285 110.521C 166.228 111.097 167.459 110.799 168.034 109.856C 168.61 108.913 168.312 107.682 167.369 107.107L 144.157 92.9452ZM 122.269 17.9301C 122.979 18.776 122.869 20.0375 122.023 20.7477C 119.209 23.1105 115.929 26.1191 112.461 29.6818C 111.69 30.4733 110.424 30.4904 109.632 29.7199C 108.841 28.9494 108.824 27.6833 109.594 26.8918C 113.154 23.235 116.532 20.1347 119.451 17.6842C 120.297 16.974 121.559 17.0841 122.269 17.9301Z"
                  transform="translate(309.827 109.453) scale(-1 1)"
                  fill="white"
                />
              </g>
              <g id="Group 5_5">
                <path
                  id="Vector_17"
                  d="M 3.92965 2.88114C -0.879014 7.04634 -1.34136 14.3586 2.91246 19.1717C 3.92967 20.375 5.03937 21.208 6.14906 21.6708C 9.47814 14.8214 13.9169 6.58357 16.9686 1.40021C 12.8072 -0.821231 7.62863 -0.451014 3.92965 2.88114Z"
                  transform="translate(521.488 411.243) scale(-1 1)"
                  fill="#1CD2F2"
                />
                <path
                  id="Vector_18"
                  d="M 5.92183 11.8408C 9.19236 11.8408 11.8436 9.19014 11.8436 5.9204C 11.8436 2.65066 9.19236 -1.12922e-05 5.92183 -1.12922e-05C 2.65131 -1.12922e-05 0 2.65066 0 5.9204C 0 9.19014 2.65131 11.8408 5.92183 11.8408Z"
                  transform="matrix(-0.608145 -0.793772 -0.793228 0.608855 536.011 411.736)"
                  fill="#1CD2F2"
                />
                <g id="Group">
                  <path
                    id="Vector_19"
                    d="M -2.44141e-05 26.3796L -2.44141e-05 1.12988e-05"
                    transform="translate(351.289 186.611) scale(-1 1)"
                    stroke="#1CD2F2"
                    strokeWidth="4"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_20"
                    d="M 0 7.96016L 3.2366 0"
                    transform="translate(329.65 189.666) scale(-1 1)"
                    stroke="#1CD2F2"
                    strokeWidth="4"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_21"
                    d="M 1.12884e-05 7.58993L 3.14411 0"
                    transform="translate(336.863 207.252) scale(-1 1)"
                    stroke="#1CD2F2"
                    strokeWidth="4"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_22"
                    d="M 1.12884e-05 13.4212L 13.2238 1.12988e-05"
                    transform="translate(325.304 210.214) scale(-1 1)"
                    stroke="#1CD2F2"
                    strokeWidth="4"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_23"
                    d="M 6.93555 16.6608L -2.25767e-05 5.64941e-06"
                    transform="translate(372.096 199.014) scale(-1 1)"
                    stroke="#1CD2F2"
                    strokeWidth="4"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                </g>
                <path
                  id="Union_3"
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M 120.89 193.851C 150.204 191.259 164.907 169.693 171.658 143.591C 182.847 100.458 180.351 56.029 173.692 54.1777C 170.398 53.3925 168.73 54.4721 167 55.592C 165.67 56.4526 164.303 57.3368 162.133 57.4174C 159.706 57.5073 159.048 56.1974 158.291 54.6891C 157.491 53.0949 156.579 51.2787 153.348 50.6603C 150.199 50.092 148.692 51.2546 147.155 52.4409C 145.939 53.3793 144.704 54.3327 142.621 54.4553C 140.551 54.5749 139.886 53.0307 139.122 51.2553C 138.11 48.9062 136.924 46.1518 132.079 46.31C 127.615 46.4819 123.364 50.092 120.334 52.6655C 118.467 54.2507 117.063 55.4428 116.358 55.1957C 111.55 53.6222 105.724 46.7729 113.307 18.9123C 120.52 -7.28205 107.018 -5.89362 96.7538 20.7636C 88.9149 41.0275 90.5516 60.5905 91.4895 71.801C 91.9568 77.3859 92.2506 80.8979 91.1128 81.3903C 87.6913 82.8713 79.8309 79.6318 78.3513 57.3246C 76.9642 36.4987 68.1792 40.2936 65.22 61.9528C 62.2607 83.6117 71.5083 97.9584 88.8934 109.158C 106.279 120.358 106.556 135.168 99.6205 137.759C 78.1289 145.689 45.8068 110.871 26.9463 90.5546C 25.1127 88.5793 23.4064 86.7411 21.8495 85.0927L 5.1117 68.5243C -5.61535 86.2033 3.16968 102.957 7.70093 108.418C 8.77784 109.757 9.95826 111.24 11.2354 112.843C 32.1106 139.058 78.7994 197.688 120.89 193.851Z"
                  transform="translate(367.313 220.366) scale(-1 1)"
                  fill="#E2197A"
                />
                <g id="Group_2">
                  <path
                    id="Vector_24"
                    d="M -2.25767e-05 7.12711C 0.277401 4.90567 0.462417 2.59166 0.647366 -2.25976e-05"
                    transform="translate(193.621 292.037) scale(-1 1)"
                    stroke="white"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_25"
                    d="M 2.25767e-05 21.1048C 5.91838 22.956 7.30552 -0.184026 9.61738 0.00109364C 12.7615 0.278774 15.9056 29.9906 19.6045 30.1757C 27.0025 30.4534 24.7832 0.741573 28.5746 1.85229C 31.9962 2.87045 28.4821 22.2155 31.9037 26.9361C 33.3833 28.9724 36.4349 28.6022 42.2608 8.88688"
                    transform="translate(236.806 296.85) scale(-1 1)"
                    stroke="white"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_26"
                    d="M -4.51535e-05 -2.25976e-05C 0.73975 4.25774 1.10969 7.96015 1.66454 10.8295"
                    transform="translate(242.077 301.293) scale(-1 1)"
                    stroke="white"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_27"
                    d="M -4.51535e-05 1.12988e-05C 0.73975 2.31401 1.38707 4.53546 1.84944 6.66434"
                    transform="translate(244.852 289.816) scale(-1 1)"
                    stroke="white"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                </g>
                <path
                  id="Vector_28"
                  d="M 214.785 103.492C 155.139 42.7729 140.066 3.43488 109.55 0.380399C 79.033 -2.67408 65.9941 13.5239 56.0069 18.3371C 50.4584 21.0213 41.3959 20.5585 31.3162 13.5239C 10.7869 -0.822869 14.9483 14.7272 21.4215 22.6874C 30.6689 34.1648 49.2563 31.2954 46.5745 34.8127C 43.8928 38.33 25.5828 33.7946 8.66002 48.1413C -3.54659 58.5081 -3.63905 72.1144 13.4687 60.3593C 30.5765 48.6042 46.9444 49.5298 47.5917 50.1777C 48.239 50.8256 31.7786 57.3973 21.514 71.2813C 12.7289 83.129 11.5267 95.4395 15.7806 97.5684C 19.3871 99.4196 26.6925 85.6281 35.0152 77.5754C 46.482 66.3757 55.8219 61.2849 57.0241 62.6733C 58.2263 64.0617 45.4648 76.5572 39.8239 89.238C 35.1077 99.9749 34.0905 111.823 38.5292 115.803C 42.8755 119.783 49.1638 100.715 53.88 92.8478C 59.1511 83.9621 75.2416 58.6006 86.1535 65.2649C 96.7881 71.8367 86.6159 79.0564 81.7148 86.2761C 76.8136 93.4032 78.0158 104.14 84.8589 106.547C 91.4246 108.861 111.861 38.7928 138.679 64.5245C 169.935 94.5139 190.927 115.432 198.51 123.022C 210.347 106.732 214.138 102.474 214.138 102.474L 214.785 103.492Z"
                  transform="translate(620.357 142.358) scale(-1 1)"
                  fill="#E2197A"
                />
                <path
                  id="Vector_29"
                  d="M 4.34885 8.69555C 6.75064 8.69555 8.69764 6.74902 8.69764 4.34781C 8.69764 1.94659 6.75064 1.12922e-05 4.34885 1.12922e-05C 1.94706 1.12922e-05 1.1295e-05 1.94659 1.1295e-05 4.34781C 1.1295e-05 6.74902 1.94706 8.69555 4.34885 8.69555Z"
                  transform="matrix(-0.608145 -0.793772 -0.793228 0.608855 533.288 395.918)"
                  fill="#1CD2F2"
                />
                <path
                  id="Vector_30"
                  d="M 21.7215 6.11648C 18.7623 0.470327 11.7343 -1.65853 6.09333 1.39595C 1.19219 3.98763 -1.02723 9.72635 0.452359 14.8171C 7.85031 12.4106 16.173 10.004 22.5538 8.43048C 22.4613 7.69 22.0914 6.85696 21.7215 6.11648Z"
                  transform="translate(536.506 296.288) scale(-1 1)"
                  fill="#1CD2F2"
                />
                <path
                  id="Vector_31"
                  d="M 5.91942 11.8455C 9.18864 11.8455 11.8389 9.19381 11.8389 5.92276C 11.8389 2.65172 9.18864 -1.12968e-05 5.91942 -1.12968e-05C 2.6502 -1.12968e-05 1.12904e-05 2.65172 1.12904e-05 5.92276C 1.12904e-05 9.19381 2.6502 11.8455 5.91942 11.8455Z"
                  transform="matrix(-0.895436 -0.44523 -0.44457 0.895764 531.672 283.009)"
                  fill="#1CD2F2"
                />
                <path
                  id="Vector_32"
                  d="M 4.34707 8.69904C 6.7479 8.69904 8.69417 6.75169 8.69417 4.34951C 8.69417 1.94734 6.7479 5.64838e-06 4.34707 5.64838e-06C 1.94624 5.64838e-06 2.25809e-05 1.94734 2.25809e-05 4.34951C 2.25809e-05 6.75169 1.94624 8.69904 4.34707 8.69904Z"
                  transform="matrix(-0.895436 -0.44523 -0.44457 0.895764 522.181 269.891)"
                  fill="#1CD2F2"
                />
                <path
                  id="Union_4"
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M 65.8744 38.1006C 70.7756 44.1172 76.3241 39.7669 82.9822 30.8809C 89.2705 33.4727 101.662 40.2295 105.084 54.3911C 89.0856 69.2009 68.0013 84.6582 60.2335 80.8633C 50.6523 76.2034 44.7636 47.7925 41.3816 31.4761C 40.1284 25.4302 39.2195 21.0449 38.5945 20.1441C 37.3149 18.3511 25.2439 17.2388 14.9376 16.2888C 6.62171 15.5222 -0.545409 14.8618 0.0327159 14.0352C 0.495118 13.2947 7.80054 10.7029 16.5856 7.83351C 23.8907 5.42677 32.306 2.92775 38.687 1.44703C 43.5881 0.336195 47.2871 -0.311754 48.3969 0.151137C 50.4362 0.932875 52.5569 7.05348 55.103 14.4019C 57.9832 22.7146 61.4077 32.5982 65.8744 38.1006Z"
                  transform="translate(552.639 303.271) scale(-1 1)"
                  fill="#828C99"
                />
                <path
                  id="Union_5"
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M 66.3673 23.2327C 69.6962 22.0293 79.2211 10.6443 87.5439 0C 94.4794 2.49902 108.628 8.88574 114.639 21.1963C 100.675 40.6338 88.931 55.8137 86.0643 57.3872C 80.3212 60.4824 58.0819 53.5759 43.3323 48.9956C 36.4699 46.8643 31.2287 45.2368 30.0248 45.3542C 28.1672 45.4905 21.2258 51.5149 14.4869 57.3635C 7.47186 63.4519 0.676332 69.3499 0.0631733 68.2168C -0.399229 67.3835 1.7276 62.293 4.77924 56.0913C 5.64069 56.4746 6.51447 56.647 7.39899 56.6377C 6.57245 56.6294 5.75983 56.4553 4.96405 56.0913C 8.2851 49.2583 12.6183 41.0439 15.7607 35.8584C 15.7376 35.8457 15.7144 35.8333 15.6912 35.8208C 17.4483 32.8589 18.8354 30.8225 19.2978 30.5447C 20.0814 30.1526 24.7499 29.645 30.9672 28.9692C 42.3586 27.7307 58.949 25.9272 66.3673 23.2327Z"
                  transform="translate(520.303 376.73) scale(-1 1)"
                  fill="#828C99"
                />
                <path
                  id="Vector_33"
                  d="M 47.4826 11.311C 43.4138 7.42346 39.2524 3.62848 35.1836 0.296321C 34.6287 -0.166479 33.8889 -0.073908 33.519 0.481452C 26.6759 9.64489 17.2435 22.8809 0.228266 47.5944C -0.141632 48.0572 -0.0492024 48.7052 0.413169 49.168L 12.8048 60.4603C 13.3596 60.9231 14.0994 60.8305 14.5618 60.2752L 47.6676 12.977C 47.945 12.3291 47.8525 11.6812 47.4826 11.311Z"
                  transform="translate(436.779 266.657) scale(-1 1)"
                  fill="#EAA736"
                />
                <path
                  id="Vector_34"
                  d="M 20.3559 0.493653C 19.6161 -0.246827 18.4139 -0.154278 17.8591 0.771322L 0.28896 25.8551C -0.173412 26.503 -0.0808925 27.5211 0.566428 28.0765L 22.1129 47.6992C 22.8527 48.3472 24.0549 48.2546 24.6098 47.4216C 30.898 38.2581 36.2615 30.2054 40.7928 23.2634C 41.2552 22.6155 41.1627 21.7825 40.6078 21.2271C 34.0421 14.0074 25.8119 5.76957 20.3559 0.493653Z"
                  transform="translate(414.461 308.112) scale(-1 1)"
                  fill="#7B16FF"
                />
                <path
                  id="Union_6"
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M 64.0847 0.833008L 63.9922 0.740479L 63.9886 0.746582L 63.1599 0C 63.1599 0 59.3684 4.25781 47.5317 20.5483L 47.5853 20.6021C 40.467 30.4114 30.3988 44.5581 16.5529 64.792C 14.3121 68.0725 12.1682 71.3289 10.1123 74.4514C 6.4834 79.9631 3.12866 85.0583 0 89.1353C 6.28821 91.7268 18.6798 98.4839 22.1938 112.646C 27.6498 107.647 32.4585 102.742 36.0649 98.6689L 51.3232 112.646C 51.3232 112.646 44.665 121.809 36.9897 131.62C 43.9253 134.119 57.9814 140.506 64.0847 152.909C 74.3494 138.655 95.8035 106.166 110.137 83.7668C 105.606 78.3057 96.8207 61.5525 107.455 43.8735L 64.0847 0.833008ZM 50.7101 23.637L 55.881 14.8206L 50.7684 23.6953L 50.7101 23.637ZM 45.5898 82.0081C 46.1448 82.4709 46.9769 82.3784 47.3469 81.823L 80.4526 34.3398C 80.7301 33.877 80.7301 33.229 80.2678 32.8589C 76.1064 28.9712 72.0375 25.1763 67.9686 21.8442C 67.5062 21.3813 66.674 21.4739 66.3041 22.0293C 59.5535 31.1926 50.0286 44.4287 33.0133 69.1423C 32.736 69.6978 32.736 70.3457 33.1982 70.7158L 45.5898 82.0081ZM 79.7129 110.332C 86.0011 101.168 91.3646 93.1152 95.8959 86.1733C 96.3583 85.5254 96.2657 84.7849 95.7109 84.0444C 89.1453 76.9172 80.915 68.772 75.4591 63.4036C 74.7192 62.7556 73.5171 62.8481 72.9623 63.6812L 55.3921 88.7651C 54.9298 89.5056 55.0222 90.4312 55.6696 90.9863L 77.2161 110.609C 77.9558 111.35 79.1581 111.165 79.7129 110.332Z"
                  transform="translate(469.657 245.017) scale(-1 1)"
                  fill="#DAE4F2"
                />
                <path
                  id="Vector_35"
                  d="M 43.6731 11.8939C 37.8473 0.971778 24.2535 -3.19342 13.3416 2.63786C 2.42959 8.46914 -1.73176 22.0755 4.09413 32.9975C 5.57372 35.6818 7.51566 37.9958 9.73504 39.847C 4.92638 46.6964 0.857527 51.5095 0.857527 51.6021C -0.437114 53.1756 -0.252166 55.4896 1.3199 56.7854C 2.05969 57.3408 2.89194 57.6185 3.72421 57.6185C 4.74143 57.6185 5.85115 57.1557 6.59095 56.3226C 6.86837 55.9524 11.3071 50.769 16.3008 43.4568C 22.0342 45.5857 28.6923 45.308 34.5182 42.161C 45.3377 36.4223 49.499 22.8159 43.6731 11.8939Z"
                  transform="translate(377.022 224.33) scale(-1 1)"
                  fill="#828C99"
                />
                <g id="Group_3">
                  <path
                    id="Vector_36"
                    d="M -2.25767e-05 9.26194C 0.184926 3.98602 4.71622 -0.17918 9.98725 0.00593966C 15.2583 0.19106 19.4196 4.72649 19.2347 10.0024"
                    transform="translate(362.849 238.254) scale(-1 1)"
                    stroke="#F6F7F8"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                </g>
              </g>
            </g>
          </g>
        </g>
      </g>
    </InlineSvg>
  </SvgWrapper>
);

export const Happy = () => (
  <SvgWrapper>
    <InlineSvg
      fillRule="evenodd"
      clipRule="evenodd"
      strokeLinejoin="round"
      strokeMiterlimit="1.414"
      xmlns="http://www.w3.org/2000/svg"
      aria-labelledby="title"
      viewBox="0 0 554 461"
      preserveAspectRatio="xMidYMid meet"
      fit
      id={'happy'}
    >
      <title id="title">{'happy'}</title>
      <g id="Canvas" fill="none">
        <g id="happy">
          <mask
            id="mask1"
            mask-type="alpha"
            maskUnits="userSpaceOnUse"
            x="0"
            y="0"
            width="568"
            height="461"
          >
            <path
              id="Union"
              d="M 568 0L 0 0L 0 220.276L 118.531 236.575C 2.85754 265.57 -60.9319 314.699 83.1118 356.271C 194.018 388.279 203.253 418.234 209.298 437.839C 213.724 452.194 216.439 461 256.102 461C 349.935 461 510.473 382.725 510.473 299.014C 510.473 296.07 510.365 293.208 510.148 290.428L 543.392 295L 568 0Z"
              fill="#C4C4C4"
            />
          </mask>
          <g mask="url(#mask1)">
            <path
              id="Ellipse 2.2"
              d="M 510.473 89.5016C 510.473 173.212 349.934 251.487 256.102 251.487C 162.269 251.487 275.224 202.203 83.1118 146.758C -109 91.3135 68.5761 22.4266 245.874 5.79096C 423.171 -10.8447 510.473 5.79096 510.473 89.5016Z"
              transform="translate(3.43323e-05 209.513)"
              fill="white"
            />
            <g id="girl">
              <g id="ice cream">
                <path
                  id="Vector"
                  d="M 0 26.9149L 41.9705 229.528C 42.3459 231.258 44.7485 231.258 45.199 229.604L 95.7288 13.3071L 34.3122 3.67096e-05L 6.60716 18.3442L 0 26.9149Z"
                  transform="translate(397.236 144.235)"
                  fill="#EAA736"
                />
                <path
                  id="Union_2"
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M 25.6326 0.810165C 25.5277 0.267928 25.0031 -0.0865638 24.4609 0.0184166C 23.9186 0.123153 23.5641 0.647811 23.669 1.19005L 26.3259 14.9274L 0.453517 31.8143C -0.00894612 32.1161 -0.139165 32.7357 0.162715 33.1981C 0.464565 33.6608 1.08419 33.7909 1.54669 33.4891L 26.736 17.048L 29.9866 33.8546L 22.604 38.6546C 22.141 38.9557 22.0097 39.5751 22.3108 40.0379C 22.6118 40.5011 23.2312 40.6324 23.6942 40.3314L 30.3964 35.9737L 33.5783 52.4252L 15.9214 63.9159C 15.4585 64.2169 15.3274 64.8365 15.6287 65.2994C 15.9299 65.7623 16.5493 65.8934 17.0123 65.5921L 33.9882 54.5448L 35.6069 62.9139C 35.7118 63.4562 36.2364 63.8107 36.7786 63.7057C 37.3209 63.6009 37.6754 63.0763 37.5706 62.534L 35.7976 53.3673L 55.8293 40.3312C 56.2922 40.0299 56.4233 39.4105 56.122 38.9476C 55.8208 38.4847 55.2013 38.3536 54.7384 38.6549L 35.3877 51.2477L 32.206 34.7972L 66.9412 12.2135C 67.4042 11.9125 67.5355 11.2931 67.2344 10.8299C 66.9334 10.367 66.314 10.2357 65.851 10.5367L 31.7961 32.6781L 28.5448 15.8673L 40.3638 8.15294C 40.8263 7.85094 40.9565 7.23131 40.6546 6.7689C 40.3527 6.3065 39.7331 6.17613 39.2707 6.47813L 28.1346 13.7467L 25.6326 0.810165Z"
                  transform="translate(394.96 190.223)"
                  fill="#F6F7F8"
                />
                <g id="Group">
                  <path
                    id="Vector_2"
                    d="M 125.766 89.9764C 124.865 88.3976 123.664 87.1946 122.312 86.2925C 122.162 86.1421 122.012 85.9918 121.711 85.8414C 121.711 85.8414 121.636 85.8414 121.636 85.7662C 121.186 85.4655 120.735 85.24 120.21 85.0144C 117.131 83.1349 118.708 81.9319 120.21 76.8948C 120.81 75.0153 121.336 73.0605 121.786 71.0306C 128.619 39.3793 108.572 8.17911 76.9628 1.33761C 45.3535 -5.50388 14.1947 14.5695 7.36232 46.2208C 4.95971 57.4228 5.93579 68.5496 9.5397 78.5488C 9.84003 79.6765 10.2905 80.5787 10.6659 81.4057L 10.6659 81.4808C 11.7171 83.7363 12.0925 84.864 7.51249 87.7961C 3.60826 89.9763 -0.145813 93.3595 0.00434953 98.0207C 0.154512 103.734 6.08595 106.516 11.0413 105.539C 12.7682 105.238 14.1947 104.562 15.7715 103.81C 15.8465 103.735 15.9216 103.734 16.0718 103.659C 15.0207 104.186 16.1469 108.696 16.4472 109.599C 18.2492 115.087 24.6311 115.989 28.9107 112.756C 32.6648 109.899 33.2654 105.238 36.1936 101.855C 37.9205 99.825 39.5723 99.7499 40.1729 102.532C 41.2991 107.569 43.4014 112.08 47.5309 115.237C 56.6157 122.154 68.5537 118.169 72.0825 107.494C 72.3078 107.193 72.533 106.892 72.7583 106.441C 72.3829 107.343 73.5091 108.772 73.8094 109.599C 74.41 111.177 75.0858 112.681 75.9868 114.11C 79.4405 119.222 86.1978 119.673 90.2522 114.937C 91.6788 113.283 92.5047 111.253 93.0303 109.148C 93.4808 107.343 93.5558 105.238 94.8322 103.81C 97.0096 101.254 100.914 105.614 102.866 106.667C 110.749 110.877 122.988 111.403 126.442 101.329C 126.592 100.953 126.667 100.577 126.817 100.201C 127.643 96.893 127.568 92.9084 125.766 89.9764Z"
                    transform="translate(378.311 63.7314)"
                    fill="#FFF5E5"
                  />
                </g>
                <path
                  id="Union_3"
                  fillRule="evenodd"
                  clipRule="evenodd"
                  d="M 194.741 11.0016C 205.076 7.8519 213.504 5.68173 219.461 4.66C 222.456 4.14609 224.718 3.94247 226.247 4.01352C 226.659 4.03256 226.982 4.0704 227.23 4.11532C 227.084 4.31943 226.881 4.56967 226.605 4.86728C 225.564 5.9874 223.813 7.42953 221.331 9.16586C 216.392 12.6195 208.907 16.9979 199.392 22.0074C 180.384 32.0157 153.491 44.4317 123.198 56.8578L 123.195 56.8592C 96.4293 67.8949 71.5534 77.0472 51.9432 83.3429C 50.8915 83.6805 50.3126 84.8067 50.6502 85.8585C 50.9879 86.9102 52.1142 87.4891 53.1659 87.1515C 72.898 80.8167 97.8757 71.6251 124.718 60.5577C 155.09 48.099 182.105 35.6305 201.256 25.5467C 210.822 20.5101 218.48 16.0406 223.623 12.4437C 226.181 10.6549 228.206 9.02109 229.536 7.58945C 230.196 6.87875 230.769 6.12875 231.127 5.35531C 231.482 4.58725 231.735 3.54086 231.299 2.46982L 231.297 2.46615C 230.86 1.39975 229.958 0.818694 229.153 0.508879C 228.349 0.199553 227.407 0.0630787 226.433 0.0179126C 224.47 -0.073396 221.871 0.188079 218.785 0.71762C 212.579 1.78207 203.962 4.00986 193.575 7.17538C 192.518 7.4974 191.923 8.61484 192.245 9.67148C 192.567 10.7281 193.685 11.3236 194.741 11.0016ZM 54.112 67.42C 55.1034 66.9332 55.5124 65.7347 55.0255 64.7433C 54.5386 63.7518 53.3401 63.3429 52.3487 63.8297C 38.5462 70.6082 27.2841 76.6976 19.6294 81.557C 15.8153 83.9784 12.8169 86.1441 10.8402 87.9784C 9.86077 88.8873 9.03796 89.8001 8.50765 90.6988C 8.00659 91.5477 7.52566 92.8072 8.0538 94.1153L 8.06017 94.1312L 8.06683 94.1468C 8.4511 95.054 9.17947 95.6046 9.8742 95.9268C 10.556 96.243 11.336 96.4046 12.1181 96.4859C 13.6862 96.6493 15.7149 96.5309 18.0769 96.2135C 22.8331 95.5746 29.4145 94.0601 37.3995 91.8351C 38.4635 91.5384 39.0857 90.4356 38.7892 89.3714C 38.4927 88.3075 37.3897 87.6854 36.3257 87.9818C 28.3935 90.1922 22.0233 91.6476 17.5444 92.2491C 15.289 92.5521 13.6292 92.6217 12.5319 92.5074C 12.3813 92.4918 12.2497 92.4735 12.1353 92.4539C 12.4169 92.0616 12.8748 91.5472 13.5611 90.9105C 15.2682 89.3263 18.0228 87.3148 21.7732 84.9339C 29.2474 80.1891 40.3596 74.1742 54.112 67.42ZM 202.997 54.3187C 203.345 53.2706 204.477 52.703 205.525 53.0509C 212.807 55.4688 218.621 57.7852 222.582 59.9051C 224.549 60.9581 226.17 62.0204 227.291 63.0951C 228.328 64.0907 229.404 65.555 229.088 67.327C 228.787 69.0338 227.361 70.016 226.118 70.5831C 224.786 71.1915 223.025 71.6226 220.979 71.9344C 216.86 72.5619 211.074 72.775 203.989 72.6239C 189.787 72.3209 170.015 70.544 147.115 67.4564C 146.021 67.3089 145.253 66.3018 145.4 65.2071C 145.548 64.1126 146.555 63.3448 147.65 63.4923C 170.475 66.5697 190.083 68.3263 204.074 68.6248C 211.085 68.7743 216.599 68.5553 220.377 67.9798C 222.28 67.69 223.618 67.3272 224.457 66.9442C 224.766 66.8033 224.952 66.6866 225.061 66.6051C 224.98 66.4767 224.823 66.2708 224.521 65.9813C 223.788 65.2777 222.537 64.4181 220.694 63.4317C 217.034 61.4727 211.474 59.2408 204.265 56.8473C 203.216 56.4991 202.649 55.367 202.997 54.3187ZM 4.81512 28.5059C 4.39309 28.1339 4.18868 27.8766 4.09054 27.7249C 4.15197 27.6798 4.23611 27.6244 4.34988 27.5599C 4.87933 27.2601 5.76653 26.9388 7.09725 26.6515C 9.73858 26.0811 13.6427 25.743 18.7054 25.6637C 28.7982 25.5059 43.1028 26.38 60.2246 28.2181C 61.3229 28.336 62.3088 27.5414 62.4267 26.443C 62.5446 25.3448 61.7499 24.359 60.6516 24.2411C 43.4612 22.3954 28.9722 21.5025 18.6428 21.6642C 13.4944 21.7447 9.28033 22.088 6.25298 22.7415C 4.74941 23.0663 3.41467 23.4928 2.37914 24.0789C 1.37142 24.6495 0.31048 25.5714 0.0554445 27.0084C 0.0555665 27.0077 0.0557191 27.0069 0.0558412 27.0062L 2.02468 27.3573L 0.0554445 27.0084C -0.284369 28.9242 1.00173 30.4764 2.16964 31.5062C 3.46234 32.6461 5.33746 33.7916 7.6322 34.9422C 12.2496 37.2577 19.0118 39.8114 27.4352 42.4859C 44.3092 47.8441 68.1486 53.7811 95.5558 59.315C 96.6386 59.5338 97.6935 58.8331 97.9121 57.7506C 98.1307 56.6678 97.4302 55.6129 96.3475 55.3941C 69.0204 49.8766 45.3332 43.9725 28.6458 38.6737C 20.2885 36.0199 13.7613 33.5411 9.42523 31.3665C 7.24322 30.2726 5.72558 29.3087 4.81512 28.5059ZM 11.8169 93.0155C 11.8164 93.0157 11.8176 93.0094 11.8218 92.9962C 11.8196 93.0086 11.8174 93.0152 11.8169 93.0155Z"
                  transform="translate(321.482 57.1838)"
                  fill="#1CD2F2"
                />
                <g id="scoop">
                  <path
                    id="Vector_3"
                    d="M 68.7746 38.7184C 64.9455 43.9059 62.0923 50.0707 57.2121 54.356C 51.2806 59.5436 41.7453 61.4231 35.2883 55.9348C 28.0804 49.77 30.1828 40.3724 35.7388 33.8316C 39.2676 29.6966 43.7725 26.4638 47.5265 22.5544C 48.4275 21.6522 49.3285 20.3742 48.878 19.1713C 48.2774 17.5925 46.0249 17.5924 44.3731 18.1939C 40.544 19.6975 37.6158 22.8551 34.162 25.1858C 30.7834 27.5164 26.1283 29.0952 22.5244 27.0653C 19.371 25.2609 18.0195 21.1259 18.6202 17.5172C 19.5962 11.6531 24.2513 8.1948 27.1795 3.38319C 27.7801 2.33066 28.2306 1.20294 28.5309 3.67096e-05C 13.5897 5.03718 2.62784 18.0435 -9.16521e-06 33.4557C 3.00325 33.5309 6.08158 34.3579 8.85959 35.7863C 14.5658 38.7936 20.3471 43.9811 22.074 50.4467C 23.951 57.7392 21.0979 65.3325 23.2002 72.7003C 23.5005 73.828 24.026 74.9558 24.6267 76.0083C 31.1588 76.7601 38.5919 76.0834 46.4754 75.1061C 69.9759 72.2492 88.7462 67.9639 84.842 35.4856C 84.6168 33.5309 84.2414 31.5762 83.7158 29.6966C 77.7844 29.4711 72.3785 33.8316 68.7746 38.7184Z"
                    transform="translate(392.206 2.14282)"
                    fill="#0059C2"
                  />
                  <path
                    id="Vector_4"
                    d="M 62.5365 24.5364C 54.8782 8.29721 37.3843 -2.00258 18.6139 0.328035C 18.3136 0.403217 17.9382 0.40318 17.6378 0.478361C 15.01 0.854268 12.5323 1.45574 10.0546 2.28273C 9.82935 3.48563 9.37887 4.61335 8.70313 5.66589C 5.77496 10.4775 1.11989 13.9358 0.143832 19.7999C -0.45682 23.4086 0.819574 27.5436 4.04808 29.348C 7.65198 31.3779 12.232 29.7991 15.6857 27.4685C 19.0644 25.1378 22.0676 21.9802 25.8968 20.4766C 27.4735 19.8751 29.801 19.8 30.4017 21.454C 30.8522 22.6569 29.9512 23.9349 29.0502 24.8371C 25.2961 28.7465 20.7913 31.9793 17.2624 36.1143C 11.7815 42.5799 9.6041 52.0528 16.8119 58.2176C 23.1938 63.7059 32.8043 61.8262 38.7357 56.6387C 43.616 52.3534 46.394 46.2638 50.2983 41.0011C 53.9022 36.1143 59.3831 31.7538 65.3146 31.9793C 64.5637 29.348 63.6628 26.867 62.5365 24.5364Z"
                    transform="translate(410.682 -0.0651855)"
                    fill="#00D5BD"
                  />
                  <path
                    id="Vector_5"
                    d="M 23.8008 39.2446C 21.6985 31.8769 24.5516 24.2836 22.6746 16.991C 21.0228 10.5254 15.2415 5.33789 9.46027 2.33064C 6.60718 0.827012 3.60393 0.075218 0.60067 3.67096e-05C 0.150181 2.48102 -1.83304e-05 5.03716 -1.83304e-05 7.59333C -1.83304e-05 9.17213 0.150163 10.8261 0.300326 12.4049C 2.25244 28.6441 8.10879 36.6133 16.2927 40.222C 18.9956 41.4249 21.9988 42.1016 25.1523 42.4775C 24.6267 41.4249 24.1011 40.3723 23.8008 39.2446Z"
                    transform="translate(391.68 35.5981)"
                    fill="#00D5BD"
                  />
                </g>
                <path
                  id="Vector_6"
                  d="M 15.2282 7.48011L 13.2761 7.1042C 12.0748 6.87866 11.324 5.7509 11.4741 4.62318L 11.7745 2.66849C 11.9997 1.46559 11.1738 0.262689 9.97252 0.0371449C 8.77122 -0.188399 7.56992 0.638614 7.34467 1.84151L 7.04433 3.79621C 6.81908 4.99911 5.69287 5.75094 4.56665 5.60058L 2.76472 5.29983C 1.56342 5.07429 0.362088 5.82607 0.0617623 6.95379C -0.238563 8.23187 0.587351 9.43475 1.86374 9.66029L 3.81583 9.96104C 5.01714 10.1866 5.76797 11.3143 5.61781 12.4421L 4.56665 18.5317C 4.3414 19.7346 5.16732 20.9375 6.36862 21.1631C 7.56992 21.3886 8.77123 20.5616 8.99647 19.3587L 10.0476 13.269C 10.2728 12.0661 11.3991 11.3143 12.5253 11.4647L 14.4774 11.7654C 15.979 11.991 17.3305 10.7881 17.1053 9.13406C 16.88 8.38225 16.1292 7.70565 15.2282 7.48011Z"
                  transform="translate(496.883 28.4937)"
                  fill="#171A21"
                />
                <path
                  id="Vector_7"
                  d="M 3.68381 7.35812C 5.71832 7.35812 7.36764 5.71093 7.36764 3.67904C 7.36764 1.64715 5.71832 -3.66616e-05 3.68381 -3.66616e-05C 1.6493 -3.66616e-05 -1.83545e-05 1.64715 -1.83545e-05 3.67904C -1.83545e-05 5.71093 1.6493 7.35812 3.68381 7.35812Z"
                  transform="matrix(0.120442 -0.992719 0.992681 0.120758 533.127 17.1709)"
                  fill="#171A21"
                />
                <path
                  id="Vector_8"
                  d="M 15.2282 7.48007L 13.2761 7.10417C 12.0748 6.87862 11.324 5.75087 11.4741 4.62315L 11.7745 2.66845C 11.9997 1.46555 11.1738 0.262652 9.9725 0.0371082C 8.7712 -0.188436 7.5699 0.638577 7.34465 1.84148L 7.04435 3.79617C 6.81911 4.99907 5.6929 5.7509 4.56668 5.60054L 2.7647 5.2998C 1.5634 5.07425 0.362116 5.82612 0.0617898 6.95384C -0.238536 8.23192 0.587332 9.4348 1.86372 9.66035L 3.81586 9.96109C 5.01716 10.1866 5.76795 11.3143 5.61779 12.442L 5.31749 14.3967C 5.09225 15.5996 5.91811 16.8025 7.11942 17.0281C 8.32072 17.2536 9.52202 16.4267 9.74727 15.2238L 10.0476 13.269C 10.2729 12.0661 11.3991 11.3144 12.5253 11.4647L 14.4774 11.7654C 15.979 11.9909 17.3305 10.788 17.1052 9.13402C 16.88 8.38221 16.1292 7.63044 15.2282 7.48007Z"
                  transform="translate(523.612 175.624)"
                  fill="#171A21"
                />
              </g>
              <g id="body">
                <path
                  id="Vector_9"
                  d="M 255.066 0.216118C 248.909 -2.1145 245.381 14.5757 215.648 42.0169C 196.728 59.459 169.398 70.2099 164.293 72.1646C 154.757 75.8485 143.045 74.9463 152.505 57.8801C 163.166 38.8593 161.815 22.8457 133.96 54.2715C 106.105 85.6973 102.801 127.047 108.132 156.593C 113.838 187.718 132.984 214.708 131.332 222.828C 129.155 233.428 112.411 229.068 93.1155 205.16C 76.8979 185.012 68.714 158.849 31.5486 142.835C 19.3855 148.398 2.64231 160.352 0.2397 183.809C -2.38815 209.596 17.2081 223.129 28.8457 228.842C 48.517 204.333 60.1547 229.669 75.3211 245.533C 105.954 277.56 147.474 305.302 170.825 294.25C 193.349 283.574 192.824 257.562 176.906 206.438C 165.644 170.351 169.774 155.691 183.138 143.361C 196.878 130.656 234.118 122.461 238.773 113.89C 243.428 105.32 233.368 100.734 233.368 98.5533C 233.368 96.2978 241.852 91.1103 242.227 87.1257C 242.603 83.1411 236.446 81.036 236.446 78.2543C 236.446 75.4726 246.882 69.834 244.93 63.9699C 242.978 58.1809 236.821 60.8875 234.118 58.7072C 231.415 56.5269 238.173 52.1664 246.807 37.9571C 258.445 19.2369 261.298 2.54674 255.066 0.216118Z"
                  transform="translate(247.735 196.044)"
                  fill="#1CD2F2"
                />
                <path
                  id="Vector_10"
                  d="M 194.159 54.2716C 196.562 30.8902 213.305 18.8612 225.468 13.2978C 220.437 11.1175 214.957 9.1628 208.8 7.28327C 192.732 2.47167 132.217 -12.339 81.687 22.3195C 31.1571 56.9781 -3.60556 121.935 0.298673 130.731C 4.20291 139.527 198.589 167.269 209.1 136.821C 209.1 136.821 212.554 117.8 222.765 99.3052C 211.127 93.5914 191.531 80.0588 194.159 54.2716Z"
                  transform="translate(53.9656 325.581)"
                  fill="#171A21"
                />
                <path
                  id="Vector_11"
                  d="M 38.2915 -1.83548e-05C 34.6125 4.05977 11.3373 24.2084 -1.83304e-05 28.7193"
                  transform="translate(450.244 245.955)"
                  stroke="#F6F7F8"
                  strokeWidth="2"
                  strokeMiterlimit="10"
                  strokeLinecap="round"
                />
              </g>
              <g id="head">
                <path
                  id="Vector_12"
                  d="M -4.58261e-06 15.3862C 6.60716 11.7023 12.1632 6.4396 16.2176 0.124372C 13.2143 -0.477078 4.35472 0.575496 -4.58261e-06 15.3862Z"
                  transform="translate(289.795 294.624)"
                  fill="#171A21"
                />
                <path
                  id="Vector_13"
                  d="M 77.2777 -1.83548e-05C 66.3158 22.4792 40.8632 22.6296 25.922 20.5245L 25.922 20.2238L 19.1646 19.2464C 16.3115 18.6449 14.5847 18.1187 14.5847 18.0435C 14.5847 18.1939 14.5096 18.4195 14.5096 18.5698L 11.5063 18.1187C 5.9503 17.3668 0.844753 21.2011 0.0939387 26.7645C -0.656876 32.3279 3.17228 37.4403 8.7283 38.1921L 15.861 39.1694C 15.9361 39.4701 16.0112 39.7709 16.0863 40.0716C 17.3627 39.9213 18.7892 39.8461 20.3659 39.8461L 23.219 40.222L 23.2941 39.8461C 30.2767 40.222 38.3855 42.4022 42.7402 49.9204C 46.7946 56.7619 46.269 64.6559 45.1428 69.9186C 52.0503 72.3244 59.5584 73.1514 67.2918 72.0237C 73.0731 71.1967 78.4039 69.3171 83.2091 66.6106C 87.6389 51.7999 96.4234 50.7474 99.4267 51.3488C 103.781 44.6577 106.484 36.7637 106.935 28.4937C 89.2907 23.1558 80.9567 9.32246 77.2777 -1.83548e-05Z"
                  transform="translate(206.661 243.324)"
                  fill="#1CD2F2"
                />
                <path
                  id="Vector_14"
                  d="M -6.10352e-06 5.11236C -6.10352e-06 2.63138 -6.10352e-06 1.2029 -6.10352e-06 0"
                  transform="translate(284.914 255.654)"
                  stroke="white"
                  strokeWidth="2"
                  strokeMiterlimit="10"
                  strokeLinecap="round"
                />
                <path
                  id="Vector_15"
                  d="M -1.2207e-05 1.57883C -1.2207e-05 1.05256 -1.2207e-05 0.526306 -1.2207e-05 3.67096e-05"
                  transform="translate(284.839 279.185)"
                  stroke="white"
                  strokeWidth="2"
                  strokeMiterlimit="10"
                  strokeLinecap="round"
                />
                <path
                  id="Vector_16"
                  d="M -4.58261e-06 10.5254C 5.2557 11.3524 11.5625 11.202 12.3133 10.8261C 12.4635 10.7509 12.5386 6.91666 12.6137 -1.83548e-05"
                  transform="translate(272.15 285.426)"
                  stroke="white"
                  strokeWidth="2"
                  strokeMiterlimit="10"
                  strokeLinecap="round"
                />
                <path
                  id="Vector_17"
                  d="M 26.5788 10.1021C 20.4972 -0.197719 7.43307 -0.498426 4.58261e-06 0.253387C 4.50489 14.4626 15.4668 25.364 28.9814 30.1004C 30.1077 24.7625 30.6332 16.9436 26.5788 10.1021Z"
                  transform="translate(222.747 283.292)"
                  fill="#171A21"
                />
                <g id="hair">
                  <path
                    id="Vector_18"
                    d="M 5.83982 25.9691C -0.166694 23.9392 -3.54536 13.1883 5.83982 4.76799C 13.348 -1.92315 27.0128 -1.24652 32.5688 4.76799C 37.1488 9.72995 36.3229 16.797 32.5688 20.932C 28.8147 25.0669 5.83982 25.9691 5.83982 25.9691Z"
                    transform="translate(237.404 205.401)"
                    fill="#171A21"
                  />
                  <path
                    id="Vector_19"
                    d="M 91.7495 39.7255C 89.4971 24.3134 79.8867 11.8334 67.1228 5.2174C 58.7137 0.856885 48.9531 -0.947503 38.9673 0.480942C 18.6202 3.48819 3.30359 19.3514 9.16522e-06 38.5978C 0.375416 38.673 46.7757 53.1078 62.693 20.4791C 66.372 29.8016 74.706 43.7101 92.2751 49.1232C 92.3502 46.0408 92.2 42.8831 91.7495 39.7255Z"
                    transform="translate(221.32 222.845)"
                    fill="#828C99"
                  />
                  <g id="Group 2">
                    <path
                      id="Union_4"
                      fillRule="evenodd"
                      clipRule="evenodd"
                      d="M 112.11 127.533C 110.201 125.786 107.759 124.054 105.453 122.419C 102.498 120.324 99.7668 118.387 98.6702 116.782C 96.8232 114.074 98.0479 111.191 99.2381 108.39C 99.4026 108.003 99.5664 107.617 99.7214 107.234C 101.598 102.648 102.124 97.4603 99.7965 92.9495C 96.9434 87.4612 90.7116 85.5816 84.9303 86.8597C 82.7967 87.3306 80.9243 88.4991 79.0783 89.6509C 77.0917 90.8907 75.1356 92.1114 72.9173 92.4231C 64.9587 93.4756 60.9794 83.4014 61.0545 77.1614C 61.1111 68.7708 64.7539 60.9791 68.3129 53.3665L 68.3148 53.3624C 69.4749 50.8809 70.6259 48.4185 71.6409 45.961C 75.8455 35.8868 78.3983 24.1585 74.494 13.5579C 72.3167 7.6187 67.6616 1.90483 61.2046 0.40117C 53.6964 -1.32783 47.0142 2.65679 44.6867 9.94927C 42.534 16.6404 42.7655 23.5728 42.9969 30.5064C 43.153 35.1807 43.309 39.8558 42.7346 44.4576C 42.5093 46.1866 42.1339 48.0662 40.8575 49.4195C 40.0316 50.2466 38.8303 50.5472 38.3798 49.1939C 38.2904 48.9251 38.2023 48.6575 38.1146 48.3912L 38.1086 48.3726C 36.5795 43.7247 35.1816 39.4751 29.295 37.8416C 22.2373 35.8868 15.4049 39.7962 11.6508 45.5853C 8.12202 50.9231 6.24499 57.99 5.49418 64.2303C 4.66828 70.9964 5.94465 77.4622 8.64759 83.7022C 14.2787 96.4078 25.9163 104.753 38.0044 110.767C 40.6323 112.045 46.2634 115.278 43.4103 123.398C 43.1851 124.075 42.9598 124.751 42.7346 125.353C 38.4549 136.48 35.9772 148.96 40.4071 160.462C 45.2873 173.318 56.3243 184.069 69.4636 188.204C 92.889 195.421 121.72 177.077 121.72 151.892C 121.645 142.268 118.492 133.322 112.11 127.533ZM 24.9562 28.7811C 31.2467 26.0867 34.1647 18.7962 31.4738 12.4971C 28.7828 6.19829 21.5019 3.27641 15.2115 5.97099C 8.92098 8.66557 6.00297 15.9561 8.6939 22.2549C 11.3848 28.5538 18.6657 31.4756 24.9562 28.7811ZM 2.71626 109.489C 10.5247 102.122 24.8653 109.715 29.0698 119.564C 29.8207 121.293 30.2711 123.022 30.4964 124.676C 31.3223 131.517 28.6193 139.787 22.9132 143.998C 19.6847 146.328 15.1047 146.479 11.8762 143.922C 9.32343 141.968 8.04705 139.111 7.37131 136.028C 7.32214 135.802 7.2781 135.544 7.22808 135.252C 6.89632 133.311 6.30111 129.83 2.19068 123.623C -0.28701 119.864 -1.33814 113.324 2.71626 109.489Z"
                      transform="translate(150.881 10.6125)"
                      fill="#FFCCE5"
                    />
                    <path
                      id="Union_5"
                      fillRule="evenodd"
                      clipRule="evenodd"
                      d="M 15.4733 20.2219L 15.8853 17.3347C 16.2607 14.7785 15.8853 12.1472 14.759 9.89182L 11.8309 3.57663C 10.4043 0.49411 6.72532 -0.858917 3.57191 0.569305C 0.493555 1.99777 -0.8579 5.68185 0.568644 8.83932L 3.49681 15.1545C 4.62303 17.4851 6.34992 19.4399 8.52729 20.7932L 10.9123 22.2715L 13.4791 27.7927L 8.3693 30.1821C 7.11857 30.7668 6.57881 32.2549 7.16368 33.5056C 7.74851 34.7563 9.23655 35.2961 10.4873 34.7112L 15.587 32.3264L 23.1193 48.5278L 10.5492 54.3894C 9.29786 54.9729 8.75645 56.4602 9.33998 57.7116C 9.92347 58.9629 11.4109 59.5044 12.6623 58.9209L 25.2273 53.0617L 33.3648 70.5649C 33.9469 71.8171 35.4338 72.3601 36.6858 71.778C 37.9378 71.196 38.4809 69.7092 37.8988 68.457L 29.7588 50.9487L 43.2955 44.6364C 44.5469 44.0529 45.0883 42.5654 44.5048 41.3139C 43.9212 40.0627 42.4338 39.5212 41.1824 40.1047L 27.6509 46.4148L 20.1163 30.2085L 25.2783 27.7946C 26.5291 27.2097 27.0688 25.7216 26.484 24.4709C 25.8991 23.2202 24.4111 22.6804 23.1603 23.2654L 18.0084 25.6745L 15.4733 20.2219Z"
                      transform="translate(207.537 118.104)"
                      fill="#E2197A"
                    />
                    <path
                      id="Vector_20"
                      d="M 113.455 0.0657907C 119.912 14.0495 98.8895 46.8285 70.8841 59.9101C 41.5273 73.5931 6.23901 67.0523 0.00725469 52.9183C -1.04389 50.5876 112.479 -2.11447 113.455 0.0657907Z"
                      transform="translate(182.496 152.665)"
                      fill="#828C99"
                    />
                    <path
                      id="Vector_21"
                      d="M 3.679 7.36778C 5.71085 7.36778 7.35798 5.71843 7.35798 3.68388C 7.35798 1.64933 5.71085 -1.83548e-05 3.679 -1.83548e-05C 1.64714 -1.83548e-05 9.16521e-06 1.64933 9.16521e-06 3.68388C 9.16521e-06 5.71843 1.64714 7.36778 3.679 7.36778Z"
                      transform="translate(285.14 131.68)"
                      fill="#171A21"
                    />
                  </g>
                </g>
                <g id="glasses">
                  <path
                    id="Vector_22"
                    d="M 17.1936 34.433C 26.6894 34.433 34.3873 26.725 34.3873 17.2166C 34.3873 7.70813 26.6894 1.83548e-05 17.1936 1.83548e-05C 7.69785 1.83548e-05 0 7.70813 0 17.2166C 0 26.725 7.69785 34.433 17.1936 34.433Z"
                    transform="translate(248.2 251.068)"
                    fill="white"
                  />
                  <path
                    id="Vector_23"
                    d="M 4.58261e-06 0.534926C 0.450493 0.459745 10.5865 -2.09642 16.4428 4.6699"
                    transform="translate(277.932 269.779)"
                    stroke="white"
                    strokeWidth="7"
                    strokeMiterlimit="10"
                  />
                  <g id="Group_2">
                    <path
                      id="Vector_24"
                      d="M 2.32752 3.67096e-05C 3.00325 2.18029 3.52882 4.43573 3.82914 6.76635C 4.27963 9.92397 4.4298 13.0816 4.27964 16.164C 3.97931 22.1785 2.4777 27.8923 9.16521e-06 33.2301C 7.95864 31.7265 13.9651 24.7346 13.9651 16.3143C 14.0402 8.72103 9.15993 2.25548 2.32752 3.67096e-05Z"
                      transform="translate(309.166 255.88)"
                      fill="#E5F0FF"
                    />
                    <path
                      id="Vector_25"
                      d="M 17.1936 9.17208C 12.3884 6.61592 8.40913 3.45834 5.25571 0C 2.0272 3.15761 4.58261e-06 7.51813 4.58261e-06 12.4049C 4.58261e-06 20.5997 5.70618 27.366 13.2894 29.1704C 17.7943 22.0282 18.2448 15.0362 17.1936 9.17208Z"
                      transform="translate(288.819 259.788)"
                      fill="white"
                    />
                    <path
                      id="Vector_26"
                      d="M 3.90423 -3.67096e-05C 4.95538 5.8641 4.50488 12.856 -9.16522e-06 19.923C 1.27638 20.2237 2.55277 20.3742 3.90423 20.3742C 5.03046 20.3742 6.08159 20.299 7.13273 20.0734C 9.61042 14.8107 11.037 9.02172 11.4124 3.00721C 8.70945 2.2554 6.23176 1.20286 3.90423 -3.67096e-05Z"
                      transform="translate(302.108 268.961)"
                      fill="#E5F0FF"
                    />
                    <path
                      id="Vector_27"
                      d="M 12.8727 17.0662C 13.0229 13.9838 12.8727 10.8262 12.4222 7.66855C 12.0468 5.33793 11.5963 3.08249 10.9206 0.90223C 9.1937 0.30078 7.31667 0 5.43963 0C 3.5626 0 1.72687 0.286968 0 0.813237C 1.65179 3.3694 4.27682 8.06341 5.32796 13.9276C 7.5804 15.1305 10.1698 16.2392 12.8727 17.0662Z"
                      transform="translate(300.648 254.977)"
                      fill="#E5F0FF"
                    />
                    <path
                      id="Vector_28"
                      d="M 11.9379 13.1567C 10.8868 7.29255 8.25895 2.55613 6.60716 -3.67096e-05C 4.12947 0.826957 1.80196 2.18026 4.58261e-06 3.98461C 3.22851 7.44295 7.13274 10.6757 11.9379 13.1567Z"
                      transform="translate(294.074 255.804)"
                      fill="white"
                    />
                  </g>
                </g>
              </g>
              <g id="jetpack">
                <g id="Group 2_2">
                  <path
                    id="Vector_29"
                    d="M 44.9424 7.6365C 42.1644 11.0197 39.3113 14.478 36.6083 18.0116C 28.3494 14.7036 19.6399 13.5007 10.6301 14.6284L 1.16987 36.1302C 4.02297 35.5288 11.9065 34.6267 21.2166 39.2879C 8.30262 58.2336 -0.707164 74.3224 0.0436507 75.0742C 17.2373 94.7717 50.6486 87.7798 52.0751 85.6747C 53.5017 83.5696 85.0359 33.3485 86.0119 19.6655C 87.5135 -2.13707 55.7541 -5.29468 44.9424 7.6365Z"
                    transform="translate(146.721 309.064)"
                    fill="#A3AFBF"
                  />
                  <path
                    id="Vector_30"
                    d="M 0.0275748 61.0241C -0.873403 59.8964 20.4497 28.6962 42.6738 5.54033C 52.8098 -4.98505 79.9142 -0.398993 77.2864 18.3211C 75.7097 30.0494 45.602 71.324 44.2505 73.1283C 42.8991 74.9327 13.6924 78.9925 0.0275748 61.0241Z"
                    transform="translate(85.9962 302.364)"
                    fill="#A3AFBF"
                  />
                </g>
              </g>
              <g id="Group 2_3">
                <path
                  id="Vector_31"
                  d="M 9.16521e-06 6.71184C 0.300335 2.72724 3.82916 -0.280034 7.80847 0.0206916C 11.7878 0.321417 14.791 3.85496 14.4907 7.83956"
                  transform="translate(258.11 261.046)"
                  stroke="#2B01B3"
                  strokeWidth="3"
                  strokeMiterlimit="10"
                  strokeLinecap="round"
                />
                <path
                  id="Vector_32"
                  d="M 0 6.71186C 0.300326 2.72725 3.82915 -0.280015 7.80847 0.0207099C 11.7878 0.321435 14.791 3.85497 14.4907 7.83958"
                  transform="translate(299.255 264.354)"
                  stroke="#2B01B3"
                  strokeWidth="3"
                  strokeMiterlimit="10"
                  strokeLinecap="round"
                />
              </g>
            </g>
          </g>
        </g>
      </g>
    </InlineSvg>
  </SvgWrapper>
);

export const Impact = () => (
  <SvgWrapper>
    <InlineSvg
      fillRule="evenodd"
      clipRule="evenodd"
      strokeLinejoin="round"
      strokeMiterlimit="1.414"
      xmlns="http://www.w3.org/2000/svg"
      aria-labelledby="title"
      viewBox="0 0 456 569"
      preserveAspectRatio="xMidYMid meet"
      fit
      id={'impact'}
    >
      <title id="title">{'impact'}</title>
      <g id="Canvas" fill="none">
        <g id="impact">
          <mask
            id="mask2"
            mask-type="alpha"
            maskUnits="userSpaceOnUse"
            x="0"
            y="0"
            width="456"
            height="569"
          >
            <path
              id="Union"
              fillRule="evenodd"
              clipRule="evenodd"
              d="M 344 0L 0 0L 0 438L 45.7853 438C 53.3735 477.466 93.7747 515.632 163.485 496.975C 201.986 486.671 216.592 512.573 229.88 536.134C 250.51 572.717 267.959 603.658 366.727 484.668C 518.935 301.297 452.872 154.695 344 231.899L 344 0Z"
              fill="#C4C4C4"
            />
          </mask>
          <g mask="url(#mask2)">
            <path
              id="Ellipse 2.3"
              d="M 81.0725 217.639C -20.6664 217.639 -14.4152 137.44 33.1069 112.783C 80.6289 88.1263 150.609 100.229 297.718 20.3694C 444.827 -59.4898 488.083 111.303 280.563 258.296C 73.0424 405.288 182.811 217.639 81.0725 217.639Z"
              transform="matrix(0.966001 -0.258538 0.2591 0.96585 28.7787 307.729)"
              fill="#F0F8FF"
            />
            <g id="Group 11">
              <g id="Group 10">
                <g id="Group 9">
                  <path
                    id="Vector"
                    d="M 60.6258 121.11C 94.1084 121.11 121.252 93.9989 121.252 60.5552C 121.252 27.1115 94.1084 0 60.6258 0C 27.1431 0 6.38534e-06 27.1115 6.38534e-06 60.5552C 6.38534e-06 93.9989 27.1431 121.11 60.6258 121.11Z"
                    transform="translate(0.212708 126.763)"
                    fill="#E2197A"
                  />
                  <path
                    id="Vector_2"
                    d="M 9.41556 18.8092C 14.6156 18.8092 18.8311 14.5986 18.8311 9.40461C 18.8311 4.21059 14.6156 0 9.41556 0C 4.21549 0 -6.38534e-06 4.21059 -6.38534e-06 9.40461C -6.38534e-06 14.5986 4.21549 18.8092 9.41556 18.8092Z"
                    transform="translate(29.0349 264.75)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_3"
                    d="M 2.56314 5.12028C 3.97871 5.12028 5.12625 3.97407 5.12625 2.56014C 5.12625 1.14621 3.97871 0 2.56314 0C 1.14756 0 0 1.14621 0 2.56014C 0 3.97407 1.14756 5.12028 2.56314 5.12028Z"
                    transform="translate(59.7402 279.118)"
                    fill="#A3AFBF"
                  />
                  <g id="Group 8">
                    <path
                      id="Union_2"
                      fillRule="evenodd"
                      clipRule="evenodd"
                      d="M 25.0704 3.35889C 30.9812 9.41968 31.7658 17.5703 31.2428 25.8254C 30.9289 31.1023 29.8304 60.5701 29.6735 70.2361C 25.8027 69.2432 22.0888 67.8848 18.5841 66.2129C 18.4806 63.8811 18.4007 61.3684 18.3196 58.8152C 17.95 47.1804 17.5538 34.7075 14.7655 34.7075C 13.575 34.7075 13.6285 36.5217 13.6906 38.6248C 13.7185 39.5708 13.7482 40.5757 13.667 41.4998C 13.5101 43.6941 12.8824 45.0002 11.8362 45.8362C 9.1685 47.9263 5.34995 47.2471 3.41453 44.6345C 2.62992 43.5374 2.05454 42.2312 1.7407 40.8728C 0.432963 35.1777 0.0145057 29.7961 0.0145057 24.5193L 0.00998909 23.8704C -0.0464074 16.0398 -0.10256 8.2356 7.02384 3.20215C 12.307 -0.559815 20.1533 -1.60474 25.0704 3.35889ZM 74.6536 44.9683C 74.8171 49.5706 74.9776 54.0864 76.0711 58.6895L 76.1174 58.8674C 76.4221 60.042 76.7995 61.4966 77.745 62.2422C 77.7973 62.3467 77.9019 62.3989 78.0065 62.4512C 73.0895 65.5862 67.7017 68.0417 62 69.7136C 62.7751 64.7004 62.4305 59.6094 62.0868 54.532C 61.9434 52.4126 61.8002 50.2954 61.7385 48.1875L 61.7182 47.5559L 61.717 47.5183C 61.5425 42.2163 61.2458 33.2012 67.9632 32.1997C 72.671 31.4683 74.2403 36.6409 74.4495 40.2458C 74.5423 41.8345 74.5981 43.4065 74.6536 44.9683ZM 78.6865 15.01C 74.6064 15.01 71.1017 18.5105 71.1017 22.5859C 71.1017 26.7136 74.5541 30.1619 78.6865 30.1619C 82.7666 30.1619 86.2713 26.6614 86.2713 22.5859C 86.2713 18.4583 82.8189 15.01 78.6865 15.01ZM 88.6774 41.0818C 88.6774 43.8518 86.4291 46.0974 83.6558 46.0974C 80.8824 46.0974 78.6341 43.8518 78.6341 41.0818C 78.6341 38.3115 80.8824 36.0659 83.6558 36.0659C 86.4291 36.0659 88.6774 38.3115 88.6774 41.0818Z"
                      transform="translate(15.2111 176.123)"
                      fill="#C21F3A"
                    />
                    <path
                      id="Vector_4"
                      d="M 20.3481 71.3183C 18.6219 66.0412 16.948 60.5552 15.3264 54.9124C 13.8618 49.8967 1.2554 4.8068 -6.38534e-06 -1.59448e-06"
                      transform="translate(38.4504 148.603)"
                      stroke="#16171A"
                      strokeWidth="4"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                    <path
                      id="Vector_5"
                      d="M 26.7821 24.3475C 28.5082 37.8797 28.1421 46.5528 25.1605 47.3888C 20.3481 48.7994 10.1479 28.9975 0 1.59448e-06"
                      transform="translate(62.6171 231.207)"
                      stroke="#16171A"
                      strokeWidth="4"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                  </g>
                </g>
                <g id="Group 7">
                  <path
                    id="Union_3"
                    fillRule="evenodd"
                    clipRule="evenodd"
                    d="M 120.959 38.0745C 114.427 44.7154 107.887 51.3645 107.639 58.3819C 107.514 61.8001 109.845 65.1475 112.275 68.6382C 115.763 73.6473 119.456 78.9517 116.393 85.1841C 113.521 91.0259 109.308 93 105.069 94.9869C 101.633 96.597 98.1795 98.2154 95.4077 101.907C 93.784 104.065 92.5729 106.456 91.4872 108.6C 89.4037 112.713 87.7817 115.916 84.5902 114.812C 81.0228 113.603 81.4692 109.495 81.9068 105.469C 82.2851 101.988 82.6567 98.5682 80.4238 97.1343C 73.4287 92.6673 65.4399 99.3487 63.5669 108.245C 62.9942 110.965 62.5145 113.913 62.038 116.841C 60.9562 123.489 59.8915 130.033 57.795 133.558C 52.8641 143.714 42.4671 150.739 30.3883 150.739C 13.6078 150.739 0 137.147 0 120.386C 0 118.095 0.267578 115.881 0.726257 113.742C 0.764465 113.609 0.793152 113.475 0.821838 113.341C 0.850525 113.208 0.87915 113.074 0.917358 112.941L 1.03204 112.483C 1.07025 112.349 1.10852 112.206 1.14673 112.063C 1.18494 111.919 1.22321 111.776 1.26141 111.643C 1.29962 111.547 1.32825 111.452 1.35687 111.356C 1.38556 111.261 1.41425 111.165 1.45251 111.07L 1.79651 110.039C 1.81799 110.018 1.82739 109.984 1.83832 109.945C 1.8468 109.915 1.8562 109.882 1.87299 109.848C 4.59894 102.484 9.56744 97.472 13.5778 93.4261C 16.9904 89.9832 19.7092 87.2405 19.7619 84.3443C 19.8129 81.2903 18.8374 78.7793 17.8918 76.3455C 16.7095 73.3023 15.5741 70.3794 16.5511 66.667C 19.7619 54.4495 37.9566 57.1221 33.752 67.3543C 29.5473 77.5862 34.2489 81.7478 38.6065 81.2134C 41.8215 80.8142 42.2396 76.7925 42.7954 71.4449C 43.4622 65.0303 44.3274 56.7078 50.456 50.4405C 55.224 45.5386 60.3317 47.1958 64.6854 48.6084C 67.4868 49.5174 69.9759 50.325 71.8616 49.2188C 75.2856 47.2071 75.9311 42.4273 76.7268 36.5345C 77.7433 29.0076 79.005 19.6646 86.6161 11.9554C 104.696 -6.40914 129.274 -2.0566 133.823 14.4371C 136.102 22.6795 128.536 30.3714 120.959 38.0745ZM 42.0468 46.47C 42.0468 49.8228 39.3257 52.5406 35.9691 52.5406C 32.6125 52.5406 29.8914 49.8228 29.8914 46.47C 29.8914 43.1175 32.6125 40.3995 35.9691 40.3995C 39.3257 40.3995 42.0468 43.1175 42.0468 46.47Z"
                    transform="translate(85.0406 0.26416)"
                    fill="#FFE6BF"
                  />
                  <g id="Group">
                    <path
                      id="Vector_6"
                      d="M 5.50427 13.9356C 14.487 6.14692 11.1233 14.2029 13.8372 15.5773C 16.3217 16.7991 21.5585 5.84148 21.0616 -1.86424e-05C 20.9469 -1.86424e-05 20.8322 -1.86424e-05 20.7175 -1.86424e-05C 11.0086 -1.86424e-05 2.82861 6.33782 1.86642e-05 15.081C 1.49076 15.8064 3.36371 15.8064 5.50427 13.9356Z"
                      transform="translate(94.4055 99.1929)"
                      fill="#6D7581"
                    />
                    <path
                      id="Vector_7"
                      d="M 14.4105 0.0494197C 9.7854 -0.752355 2.75216 8.41079 1.86642e-05 12.2288C 3.32553 14.3287 7.30084 15.5122 11.5055 15.5122C 13.5696 15.5122 15.5573 15.2068 17.4303 14.6723C 16.2835 9.67073 18.6916 0.813014 14.4105 0.0494197Z"
                      transform="translate(103.579 127.167)"
                      fill="#6D7581"
                    />
                    <path
                      id="Vector_8"
                      d="M 39.0652 19.5099C 36.9246 18.7463 30.6176 28.8257 29.2798 21.7243C 28.133 15.6919 32.1466 8.1323 34.6312 4.19979C 31.1145 1.64175 26.7952 0.0763781 22.1318 1.86424e-05C 22.6288 5.84152 17.392 16.7991 14.9075 15.5773C 12.1935 14.2029 15.5573 6.14696 6.57456 13.9356C 4.47223 15.7682 2.56101 15.7682 1.03204 15.081C 0.344009 17.1809 9.33209e-06 19.4335 9.33209e-06 21.7625C 9.33209e-06 29.5511 4.08997 36.3853 10.2441 40.2032C 12.9962 36.3853 20.0295 27.2221 24.6546 28.0239C 28.9358 28.7875 26.5276 37.6452 27.6744 42.6849C 32.1084 41.425 35.9308 38.8288 38.7211 35.3544C 36.7335 29.8566 40.9764 20.1971 39.0652 19.5099Z"
                      transform="translate(93.2971 99.2314)"
                      fill="#A3AFBF"
                    />
                    <path
                      id="Vector_9"
                      d="M 5.55284 -1.86424e-05C 3.06827 3.97067 -0.945276 11.4921 0.201451 17.5245C 1.5393 24.6259 7.84629 14.5465 9.98684 15.3101C 11.8981 15.9973 7.65519 25.6568 9.68108 31.1165C 12.6626 27.3749 14.4591 22.6788 14.4591 17.5245C 14.4591 10.3467 10.9425 3.97067 5.55284 -1.86424e-05Z"
                      transform="translate(122.414 103.393)"
                      fill="#6D7581"
                    />
                    <path
                      id="Vector_10"
                      d="M 5.00739 10.0031C 7.77289 10.0031 10.0148 7.7638 10.0148 5.00153C 10.0148 2.23925 7.77289 -9.32123e-06 5.00739 -9.32123e-06C 2.2419 -9.32123e-06 -1.86642e-05 2.23925 -1.86642e-05 5.00153C -1.86642e-05 7.7638 2.2419 10.0031 5.00739 10.0031Z"
                      transform="translate(98.1898 118.245)"
                      fill="#6D7581"
                    />
                    <path
                      id="Vector_11"
                      d="M 2.48457 4.96336C 3.85676 4.96336 4.96914 3.85227 4.96914 2.48167C 4.96914 1.11108 3.85676 -9.32122e-06 2.48457 -9.32122e-06C 1.11237 -9.32122e-06 -9.33209e-06 1.11108 -9.33209e-06 2.48167C -9.33209e-06 3.85227 1.11237 4.96336 2.48457 4.96336Z"
                      transform="translate(112.294 115.763)"
                      fill="#6D7581"
                    />
                  </g>
                  <path
                    id="Vector_12"
                    d="M -9.33209e-06 7.71232L 7.91243 -1.86424e-05"
                    transform="translate(175.364 50.5139)"
                    stroke="#F6F7F8"
                    strokeWidth="3"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_13"
                    d="M 0 33.5218L 34.3636 1.86424e-05"
                    transform="translate(135.191 63.9148)"
                    stroke="#F6F7F8"
                    strokeWidth="3"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_14"
                    d="M 9.33209e-06 15.1574L 15.5573 -1.86424e-05"
                    transform="translate(165.923 65.022)"
                    stroke="#F6F7F8"
                    strokeWidth="3"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_15"
                    d="M -1.86642e-05 3.05436L 3.1344 -1.86425e-05"
                    transform="translate(140.81 103.393)"
                    stroke="#F6F7F8"
                    strokeWidth="3"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_16"
                    d="M -9.33209e-06 4.84882L 5.00736 9.32123e-06"
                    transform="translate(112.294 88.3882)"
                    stroke="#F6F7F8"
                    strokeWidth="3"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_17"
                    d="M -1.86642e-05 16.2646L 16.6658 1.86425e-05"
                    transform="translate(134.312 66.3965)"
                    stroke="#F6F7F8"
                    strokeWidth="3"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_18"
                    d="M 9.33209e-06 7.67413L 7.91241 9.32122e-06"
                    transform="translate(123.112 85.9065)"
                    stroke="#F6F7F8"
                    strokeWidth="3"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                </g>
              </g>
              <g id="Group 4">
                <g id="Group 4_2">
                  <path
                    id="Vector_19"
                    d="M 187.643 36.8965C 180.682 35.9802 175.07 35.1178 171.508 28.8114C 166.759 20.4029 159.097 15.1746 149.221 15.6597C 144.742 15.8753 140.317 17.0611 136 18.2469C 131.953 19.3249 127.906 20.4568 123.858 21.5348C 114.091 24.176 106.051 11.8867 97.7942 7.4129C 88.0268 2.13064 77.1261 -0.294864 66.0097 0.02854C 48.6334 0.513646 33.1459 8.437 25.3212 24.4455C 21.22 32.8001 17.9822 42.0171 18.306 51.3419C 18.6298 61.9603 25.1054 72.7944 23.9722 76.1901C 23.3786 78.0227 21.4898 79.1546 19.709 80.017C 4.1136 87.4553 -0.635164 99.8525 0.0663609 109.285C 1.30752 125.509 23.3246 130.037 28.2892 113.921C 28.8828 112.034 29.0447 110.04 29.2606 108.099C 29.2606 107.992 29.3685 107.452 29.4225 107.075C 29.5304 106.698 29.6923 105.997 29.7463 105.889C 29.7463 105.782 29.8002 105.728 29.8002 105.674C 30.07 105.135 30.3938 104.596 30.7176 104.057C 30.7716 104.003 30.8255 103.895 30.8255 103.841C 31.2572 103.356 31.6889 102.871 32.1206 102.44C 32.4984 102.062 32.8761 101.739 33.1999 101.416C 33.3618 101.254 33.4697 101.2 33.5237 101.092C 33.5777 101.038 33.6856 100.984 33.7935 100.931C 34.8728 100.176 35.952 99.4752 37.0853 98.7745C 39.3517 97.427 41.6722 96.2951 44.0466 95.1632C 45.5036 94.4625 46.5828 93.2766 47.3383 91.8752C 53.5981 95.2709 60.7752 97.1575 68.3841 97.1575C 92.8295 97.1575 112.688 77.3759 112.688 52.9051C 112.688 51.3958 112.634 49.8866 112.472 48.3774C 113.767 48.1618 115.062 48.0001 116.304 47.8384C 116.789 48.5391 117.437 49.1859 118.3 49.671C 121.16 51.3419 125.585 50.4795 127.15 47.3533C 127.258 47.0838 127.42 46.8682 127.528 46.6526C 129.363 46.4909 131.252 46.383 133.086 46.2752C 139.778 45.8979 146.523 45.7363 153.215 45.9519C 156.237 46.0597 159.798 46.1135 162.874 47.0838C 164.547 48.1618 166.274 49.132 168.109 50.0483C 168.486 50.21 168.864 50.3717 169.242 50.4795C 170.321 51.0724 171.454 51.5575 172.749 51.8809C 175.933 52.6355 178.685 51.8809 181.815 51.5575C 188.075 50.9646 193.957 55.1688 195.576 61.1518C 197.141 66.9192 204.318 67.027 207.394 62.7149C 213.87 53.5518 209.391 39.7533 187.643 36.8965Z"
                    transform="translate(165.052 414.13)"
                    fill="#00D5BD"
                  />
                  <path
                    id="Vector_20"
                    d="M 15.4016 30.7674C 23.9077 30.7674 30.8033 23.8799 30.8033 15.3837C 30.8033 6.88752 23.9077 -1.64008e-05 15.4016 -1.64008e-05C 6.89554 -1.64008e-05 -1.64199e-05 6.88752 -1.64199e-05 15.3837C -1.64199e-05 23.8799 6.89554 30.7674 15.4016 30.7674Z"
                    transform="translate(280.613 366.518)"
                    fill="#00D5BD"
                  />
                </g>
                <g id="Group 2">
                  <path
                    id="Vector_21"
                    d="M 131.622 151.221C 128.753 143.809 129.862 136.588 128.868 128.909C 128.638 127.151 128.256 125.355 127.223 123.904C 125.616 121.573 123.206 121.306 120.682 121.993C 108.327 125.355 95.0155 124.171 85.2997 115.154C 80.2124 110.455 76.1577 104.342 76.6168 97.1591C 76.9993 90.7404 80.3654 84.7038 84.5347 80.0426C 87.1358 77.1007 90.6166 75.0757 93.1412 72.0956C 98.0373 66.3265 98.8788 58.4941 100.103 51.3113C 101.136 45.2365 105.037 34.042 112.917 34.8443C 118.272 35.3792 120.414 40.8809 120.72 45.5803C 120.95 49.2482 120.452 52.6867 119.534 56.24C 118.54 60.2516 114.753 66.7849 120.146 69.3447C 121.906 70.1853 124.048 69.9943 125.693 68.9627C 132.387 64.8364 127.376 56.0489 126.267 50.4325C 125.31 45.6185 125.234 40.6135 126.611 35.8377C 128.179 30.3359 132.348 25.4073 137.627 23.1149C 143.212 20.7079 149.676 21.5867 154.343 25.5219C 159.201 29.6482 161.687 35.6849 161.955 41.9507C 162.261 48.7133 160.922 55.5904 158.78 62.0091C 156.638 68.3132 153.234 74.1206 151.053 80.4246C 149.485 85.0094 147.458 91.6574 153.042 94.4082C 155.108 95.4398 157.632 95.5544 159.774 94.7139C 163.255 93.4148 164.824 90.2055 165.512 86.7669C 168.075 74.2352 180.047 64.3397 193.168 66.8231C 195.998 67.358 198.599 68.6571 200.894 70.3763C 187.162 29.4572 148.49 -1.86555e-05 102.933 -1.86555e-05C 65.524 -1.86555e-05 32.7429 19.8674 14.6119 49.6302C 15.4152 49.9741 16.1802 50.4708 16.9069 51.2349C 21.9943 56.622 19.202 65.9062 19.0873 72.3631C 19.049 74.1588 19.2402 76.1073 20.3878 77.4827C 24.9014 82.717 32.4751 76.3366 35.7264 73.0126C 39.8193 68.7717 43.6444 64.1105 49.1525 61.6271C 54.1634 59.3729 60.0541 59.1054 64.7589 62.3148C 75.8135 69.8415 67.1688 84.1689 60.3218 91.4663C 59.9776 91.8102 59.6716 92.1541 59.3273 92.4979C 52.0979 99.6425 43.1471 103.769 33.6609 106.864C 23.5244 110.149 12.7376 111.83 2.10381 112.403C 1.37704 112.442 0.650267 112.327 0 112.06C 4.47537 164.899 48.8465 206.391 102.933 206.391C 133.725 206.391 161.381 192.943 180.315 171.585C 176.911 172.846 173.354 173.687 169.72 174.145C 153.348 176.246 137.551 166.542 131.622 151.221Z"
                    transform="translate(193.043 446.757)"
                    fill="#5F45FC"
                  />
                  <path
                    id="Vector_22"
                    d="M 34.0434 57.2333C 43.4914 54.1386 52.4804 50.0123 59.7098 42.8677C 60.0541 42.5238 60.3983 42.18 60.7043 41.8361C 67.5513 34.5387 76.196 20.2112 65.1415 12.6845C 60.4366 9.47519 54.5459 9.74266 49.535 11.9968C 44.0269 14.4803 40.2401 19.1414 36.1089 23.3823C 32.8576 26.7445 25.2839 33.0868 20.7703 27.8525C 19.5845 26.4771 19.4315 24.5286 19.4698 22.7329C 19.5845 16.2378 22.3768 6.95356 17.2894 1.60465C 16.5627 0.840524 15.7977 0.343858 14.9944 0C 5.46989 15.6265 -9.33862e-06 33.9655 -9.33862e-06 53.5655C -9.33862e-06 56.5456 0.114744 59.4875 0.382501 62.3912C 1.03277 62.6586 1.72129 62.7732 2.48631 62.735C 13.1583 62.2001 23.9451 60.5191 34.0434 57.2333Z"
                    transform="translate(192.699 496.349)"
                    fill="#2B01B3"
                  />
                  <path
                    id="Vector_23"
                    d="M 124.313 48.5954C 122.018 46.8761 119.417 45.577 116.586 45.0421C 103.466 42.5587 91.4936 52.4542 88.9308 64.986C 88.2423 68.4245 86.674 71.6339 83.1932 72.9329C 81.0511 73.7352 78.5265 73.6206 76.461 72.6273C 70.9146 69.9146 72.9419 63.2666 74.4719 58.6436C 76.614 52.3396 80.0566 46.5322 82.1986 40.2281C 84.3789 33.8095 85.7177 26.9705 85.3735 20.1697C 85.0675 13.8657 82.6194 7.86725 77.7615 3.74095C 73.0949 -0.194318 66.6305 -1.07309 61.0458 1.33392C 55.7672 3.62631 51.5978 8.55497 50.0295 14.0567C 48.6525 18.8325 48.7672 23.8375 49.6853 28.6516C 50.7945 34.2679 55.8054 43.0172 49.1115 47.1817C 47.4667 48.2133 45.2864 48.4043 43.5651 47.5638C 38.1717 45.0039 41.9203 38.4707 42.9531 34.459C 43.8329 30.9058 44.3301 27.4672 44.1389 23.7994C 43.8711 19.1382 41.7291 13.6364 36.3357 13.0633C 28.456 12.261 24.5544 23.4173 23.5216 29.5303C 22.3358 36.6749 21.456 44.5455 16.5599 50.3147C 14.0353 53.2948 10.5545 55.3197 7.95343 58.2616C 3.78407 62.9228 0.456251 68.9594 0.0354903 75.3781C -0.423522 82.5609 3.63107 88.6357 8.71845 93.3733C 18.4342 102.39 31.7455 103.574 44.1006 100.212C 46.6252 99.5246 49.035 99.7921 50.6415 102.123C 51.6361 103.574 52.0568 105.37 52.2863 107.128C 53.2809 114.769 52.1716 122.028 55.0404 129.44C 60.9311 144.761 76.7288 154.466 93.1384 152.364C 96.7723 151.906 100.33 151.065 103.734 149.804C 119.876 131.58 129.668 107.663 129.668 81.4147C 129.668 69.9528 127.794 58.9111 124.313 48.5954ZM 41.1936 45.5389C 41.1936 45.5389 41.1936 45.5006 41.1936 45.5389C 41.2701 45.6535 41.3466 45.7299 41.3466 45.7681C 41.3083 45.6917 41.2318 45.6153 41.1936 45.5389ZM 60.5868 33.7712C 60.7781 34.1533 60.8928 34.5354 60.9311 34.9939C 60.8546 34.6118 60.7398 34.1915 60.5868 33.7712Z"
                    transform="translate(269.663 468.538)"
                    fill="#2B01B3"
                  />
                  <path
                    id="Vector_24"
                    d="M 22.2238 23.3824C 28.1527 20.7079 33.1636 12.761 35.3057 5.15789C 25.1309 1.79572 14.2676 1.86555e-05 2.98357 1.86555e-05C 1.98905 1.86555e-05 0.994526 9.32832e-06 0 0.0382158C 1.41529 6.34229 2.60108 12.9902 6.46443 18.2627C 10.0218 23.1531 16.3332 26.0568 22.2238 23.3824Z"
                    transform="translate(293.07 446.031)"
                    fill="#2B01B3"
                  />
                  <path
                    id="Vector_25"
                    d="M 1.5142 13.3341C 1.24645 16.5052 0.749194 19.6381 0.328433 22.7711C -0.054077 25.4837 -0.321815 28.3874 0.825715 30.9854C 3.73279 37.557 12.3775 36.4872 17.5031 33.4307C 19.7982 32.0552 21.5195 29.9921 23.6615 28.4256C 17.6944 17.6132 9.89117 7.98515 0.596171 0C 1.7437 4.27913 1.89671 8.82571 1.5142 13.3341Z"
                    transform="translate(362.932 471.133)"
                    fill="#1CD2F2"
                  />
                  <path
                    id="Vector_26"
                    d="M 0.045886 5.57816C 0.313643 8.48186 2.18794 10.8507 5.20977 11.1181C 7.61958 11.3473 9.83812 9.97189 11.0621 7.94695C 11.6742 6.95358 12.0185 5.84559 12.095 4.6994C 8.72886 2.9419 5.248 1.37541 1.65241 -1.86555e-05C 0.237122 1.45183 -0.145369 3.59143 0.045886 5.57816Z"
                    transform="translate(331.428 452.87)"
                    fill="#2B01B3"
                  />
                  <path
                    id="Vector_27"
                    d="M 7.4972 14.9769C 11.6378 14.9769 14.9944 11.6243 14.9944 7.48849C 14.9944 3.35272 11.6378 -1.86555e-05 7.4972 -1.86555e-05C 3.35661 -1.86555e-05 9.33862e-06 3.35272 9.33862e-06 7.48849C 9.33862e-06 11.6243 3.35661 14.9769 7.4972 14.9769Z"
                    transform="translate(268.551 496.043)"
                    fill="#1CD2F2"
                  />
                </g>
                <g id="Group 3">
                  <path
                    id="Vector_28"
                    d="M 50.711 33.3873L 16.4777 3.28016e-05L -8.20996e-06 20.7579L 40.1518 47.4947C 40.2864 47.629 40.4209 47.7634 40.5554 47.8305C 43.6491 49.9802 48.4244 48.5023 51.1818 44.4717C 54.0066 40.5082 53.8048 35.537 50.711 33.3873Z"
                    transform="translate(332.871 272.939)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_29"
                    d="M 49.8289 2.88866C 38.2609 16.7273 27.4327 11.4874 14.7885 7.5911C 6.17975 4.97117 -2.49627 5.77728 0.664761 10.0095C 5.84347 16.9288 30.3246 34.1934 37.5883 35.6713C 39.4042 36.0744 49.2236 23.5122 57.1598 13.234C 55.5457 7.72547 53.6625 3.22451 52.1829 -1.64008e-05L 49.8289 2.88866Z"
                    transform="translate(220.494 336.288)"
                    fill="#171A21"
                  />
                  <path
                    id="Vector_30"
                    d="M 5.31323 42.3891L 34.0316 7.25523L 24.2122 0L -8.20996e-06 29.6254C 1.47962 32.8499 3.29555 37.3509 4.97695 42.8594C 5.04421 42.7251 5.17872 42.5235 5.31323 42.3891Z"
                    transform="translate(272.677 306.662)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_31"
                    d="M 7.96711 36.9477C 1.2415 42.9266 -2.8611 50.5176 2.38487 50.1146C 6.95828 49.7787 17.7193 44.7403 26.8661 42.0532C 34.8695 39.702 41.3934 39.7692 43.8146 37.2836C 44.958 36.0744 45.2269 19.8174 46.9756 6.31471C 42.604 3.69478 38.2323 1.54507 34.9368 -1.64008e-05C 28.8838 22.3702 19.9387 26.4008 7.96711 36.9477Z"
                    transform="translate(266.593 411.191)"
                    fill="#171A21"
                  />
                  <path
                    id="Vector_32"
                    d="M 12.8459 81.4866L 22.9343 2.55274L 10.6937 3.28016e-05L 0.134528 81.7553C 0.0672724 81.8897 0.0672642 82.024 8.20996e-06 82.1584C 3.29555 83.6363 7.66717 85.8532 12.0388 88.4731C 12.3078 86.6593 12.5769 84.8455 12.8459 83.166C 12.9804 82.6286 12.9804 82.024 12.8459 81.4866Z"
                    transform="translate(301.53 329.032)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_33"
                    d="M 40.2191 27.7444C 36.789 28.7521 33.0227 29.8269 29.1218 30.7674C 25.8935 31.5735 23.2706 30.9689 20.9166 24.7886L 11.4335 -3.28016e-05L 1.64199e-05 4.03063L 11.4335 33.3202C 17.4193 48.7039 20.1768 47.6962 28.9201 44.5388L 37.5962 41.3815C 38.6722 40.9785 39.6811 40.6425 40.6899 40.3066C 40.2864 37.7539 39.681 32.514 40.2191 27.7444Z"
                    transform="translate(336.638 323.591)"
                    fill="#828C99"
                  />
                  <path
                    id="Vector_34"
                    d="M 39.1538 34.8395C 38.2122 26.2408 28.0566 5.07978 22.5416 0.175804C 21.4655 -0.831862 12.6549 2.66135 0.212549 6.35612C -0.325499 11.1257 0.279855 16.3656 0.683391 18.9183C 14.6726 14.2831 16.4213 17.7092 26.9132 28.1889C 33.3026 34.5708 39.7591 40.0794 39.1538 34.8395Z"
                    transform="translate(376.644 344.979)"
                    fill="#171A21"
                  />
                  <g id="Group 2_2">
                    <path
                      id="Vector_35"
                      d="M 100.212 55.9591C 100.951 56.6309 101.826 56.9667 102.7 57.0339C 103.843 57.1011 105.054 56.698 105.928 55.7575C 107.475 54.1453 107.408 51.5925 105.794 50.0474L 86.693 31.9766C 85.0789 30.4315 82.5231 30.4987 80.9763 32.111C 79.4294 33.7233 79.4966 36.276 81.1108 37.8211L 88.3744 44.6732L 83.801 49.8458L 32.6192 0L -8.20996e-06 41.1127L 39.6138 67.4465L 24.5484 85.8532L 34.3678 93.1083L 39.5465 86.7264L 43.3801 88.6746L 39.8828 108.223L 52.1234 110.776L 55.6207 91.2274L 58.1764 91.093L 64.2968 106.745L 75.7303 102.715L 69.9463 87.5998L 79.5639 93.9817C 79.8329 94.2504 80.1019 94.4519 80.4382 94.6534C 86.5585 98.8856 95.9743 95.9298 101.489 88.07C 107.004 80.143 106.534 70.3351 100.413 66.0357L 100.48 65.9685L 89.6523 55.4216L 94.2929 50.1146L 100.212 55.9591Z"
                      transform="translate(272.341 220.675)"
                      fill="#7B16FF"
                    />
                    <g id="Group_2">
                      <path
                        id="Vector_36"
                        d="M 8.20996e-06 21.6313L 2.35397 -1.64008e-05"
                        transform="translate(292.114 182.787)"
                        stroke="#EAA736"
                        strokeWidth="4"
                        strokeMiterlimit="10"
                        strokeLinecap="round"
                      />
                      <path
                        id="Vector_37"
                        d="M 2.4212 8.26289L 0 0"
                        transform="translate(269.785 178.689)"
                        stroke="#EAA736"
                        strokeWidth="4"
                        strokeMiterlimit="10"
                        strokeLinecap="round"
                      />
                      <path
                        id="Vector_38"
                        d="M 2.28669 7.92699L 8.20996e-06 -1.64008e-05"
                        transform="translate(275.3 196.894)"
                        stroke="#EAA736"
                        strokeWidth="4"
                        strokeMiterlimit="10"
                        strokeLinecap="round"
                      />
                      <path
                        id="Vector_39"
                        d="M 11.7698 14.7119L -1.64199e-05 -1.64008e-05"
                        transform="translate(253.375 197.565)"
                        stroke="#EAA736"
                        strokeWidth="4"
                        strokeMiterlimit="10"
                        strokeLinecap="round"
                      />
                      <path
                        id="Vector_40"
                        d="M 1.64199e-05 15.9211L 8.60878 1.64008e-05"
                        transform="translate(305.7 192.729)"
                        stroke="#EAA736"
                        strokeWidth="4"
                        strokeMiterlimit="10"
                        strokeLinecap="round"
                      />
                      <path
                        id="Vector_41"
                        d="M -8.20996e-06 16.5257L 20.3786 -1.64008e-05"
                        transform="translate(316.73 201.26)"
                        stroke="#EAA736"
                        strokeWidth="4"
                        strokeMiterlimit="10"
                        strokeLinecap="round"
                      />
                    </g>
                    <path
                      id="Vector_42"
                      d="M -8.20996e-06 3.28016e-05L 31.6103 20.2205"
                      transform="translate(298.234 279.993)"
                      stroke="#F6F7F8"
                      strokeWidth="2"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                    <path
                      id="Vector_43"
                      d="M 6.5911 3.28016e-05C 8.74329 10.0767 6.12031 20.2205 1.64199e-05 27.8788"
                      transform="translate(314.107 233.976)"
                      stroke="#F6F7F8"
                      strokeWidth="2"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                    <path
                      id="Vector_44"
                      d="M 26.1994 52.4594C 40.669 52.4594 52.3989 40.716 52.3989 26.2297C 52.3989 11.7434 40.669 -3.28397e-05 26.1994 -3.28397e-05C 11.7299 -3.28397e-05 -8.20045e-06 11.7434 -8.20045e-06 26.2297C -8.20045e-06 40.716 11.7299 52.4594 26.1994 52.4594Z"
                      transform="matrix(0.0659777 -0.997795 0.997805 0.0658249 260.205 265.414)"
                      fill="#1CD2F2"
                    />
                    <g id="Group_3">
                      <path
                        id="Vector_45"
                        d="M 15.6587 11.1551L 20.6357 3.22816C 20.7702 2.95944 20.7702 2.62351 20.5012 2.42197C 18.2817 0.809708 15.5915 -0.0635861 12.565 0.00359164C 6.44466 0.137947 1.26593 4.70605 0.189835 10.6849C -1.22254 18.9477 5.4358 26.3373 13.8428 25.7327C 19.2233 25.3968 23.864 21.5677 25.3436 16.395C 25.6799 15.253 25.8144 14.1109 25.8144 12.9689C 25.8144 12.633 25.5453 12.4315 25.2763 12.3643L 15.7932 11.5582C 15.6587 11.491 15.5915 11.2894 15.6587 11.1551Z"
                        transform="translate(275.177 228.128)"
                        fill="#171A21"
                      />
                    </g>
                  </g>
                </g>
              </g>
            </g>
          </g>
        </g>
      </g>
    </InlineSvg>
  </SvgWrapper>
);

export const Ideas = () => (
  <SvgWrapper>
    <InlineSvg
      fillRule="evenodd"
      clipRule="evenodd"
      strokeLinejoin="round"
      strokeMiterlimit="1.414"
      xmlns="http://www.w3.org/2000/svg"
      aria-labelledby="title"
      viewBox="0 0 620 454"
      preserveAspectRatio="xMidYMid meet"
      fit
      id={'ideas'}
    >
      <title id="title">{'ideas'}</title>
      <g id="Canvas" fill="none">
        <g id="ideas">
          <mask
            id="mask3"
            mask-type="alpha"
            maskUnits="userSpaceOnUse"
            x="-1"
            y="-4"
            width="621"
            height="458"
          >
            <path
              id="Union"
              fillRule="evenodd"
              clipRule="evenodd"
              d="M 421.015 0L 58.6842 0L 58.6842 263.75C -29.9225 261.284 -8.4684 295.332 58.6842 334.842L 58.6842 458L 421.015 458L 421.015 448.396C 606.994 446.15 620 341.231 620 270.508C 620 220.867 502.811 45.5466 421.015 10.5862L 421.015 0Z"
              transform="translate(620 -4) scale(-1 1)"
              fill="#C4C4C4"
            />
          </mask>
          <g mask="url(#mask3)">
            <path
              id="Ellipse"
              d="M 620 266.013C 620 337.504 606.71 443.938 414.893 443.938C 223.076 443.938 -218.83 217.202 130.287 266.013C 479.404 314.824 316.23 266.013 346.588 64.1906C 376.946 -137.632 620 194.522 620 266.013Z"
              transform="translate(620 0.495117) scale(-1 1)"
              fill="white"
            />
            <g id="Group 6">
              <g id="Group 5">
                <g id="Group 5_2">
                  <g id="Group 5_3">
                    <path
                      id="Vector"
                      d="M 31.836 67.901C 31.836 67.901 56.8385 48.4318 63.1896 31.2152L 41.6441 1.96415e-05L 0 28.8016L 31.836 67.901Z"
                      transform="translate(208.326 110.287) scale(-1 1)"
                      fill="#16171A"
                    />
                    <path
                      id="Vector_2"
                      d="M 9.81371e-06 16.3328C 9.81371e-06 16.3328 27.0928 -0.159743 45.4226 0.00115991L 66.9681 31.2163L 25.3241 60.018L 9.81371e-06 16.3328Z"
                      transform="translate(239.519 70.3823) scale(-1 1)"
                      fill="#16171A"
                    />
                    <path
                      id="Vector_3"
                      d="M 80.3135 1.96415e-05L 69.7819 7.24065L 9.81371e-06 55.431L 4.66285 62.189C 40.4381 42.6393 52.7384 59.6145 76.3742 71.8432C 92.6942 80.2906 97.6786 80.1297 113.114 69.9928C 116.169 67.9815 119.626 65.568 123.646 62.7522L 80.3135 1.96415e-05Z"
                      transform="translate(264.039 152.122) scale(-1 1)"
                      fill="#C5D3E7"
                    />
                    <path
                      id="Vector_4"
                      d="M 41.644 9.82073e-06C 37.6243 2.81581 34.087 5.14888 31.1928 7.32107C 16.2396 18.182 14.3101 22.7678 16.4004 41.0303C 19.4553 67.4988 30.9517 85.0372 0 111.586L 4.66284 118.344L 74.4447 70.1537L 84.9764 62.9131L 41.644 9.82073e-06Z"
                      transform="translate(302.387 40.5359) scale(-1 1)"
                      fill="#C5D3E7"
                    />
                    <path
                      id="Vector_5"
                      d="M 37.5439 32.1001C 33.6046 31.4565 27.0123 29.1234 23.2338 23.7332C 19.6161 18.4234 19.7769 11.585 20.42 7.64291C 16.5611 6.91885 9.48649 5.14891 5.86876 1.96415e-05L 1.96274e-05 21.8023C 4.2609 23.9745 8.28055 27.4339 11.4159 31.9392C 14.5513 36.4445 16.32 41.4325 16.8023 46.1791L 39.3126 48.3513C 35.8557 43.0415 36.74 35.8813 37.5439 32.1001Z"
                      transform="translate(352.311 192.75) scale(-1 1)"
                      fill="#EAA736"
                    />
                    <path
                      id="Vector_6"
                      d="M 14.6317 74.3372C 13.9885 78.1988 13.8277 85.1177 17.4455 90.4275C 21.1436 95.8177 27.8163 98.1508 31.7556 98.7944C 30.9516 102.576 30.1477 109.736 33.4439 115.126L 33.7654 115.126L 129.917 48.7536L 96.2315 0L 0.0804037 66.3725L -1.96274e-05 66.7747C 3.6981 71.8431 10.7728 73.6131 14.6317 74.3372Z"
                      transform="translate(346.523 126.056) scale(-1 1)"
                      fill="#E2197A"
                    />
                    <path
                      id="Vector_7"
                      d="M 48.2364 50.4825C 50.4874 48.8734 52.0953 46.5403 52.5776 43.805C 53.462 38.817 51.6129 30.7718 42.9303 18.2214C 34.4086 5.83188 27.4947 1.24617 22.4299 0.200304C 19.6965 -0.362856 16.8023 0.280736 14.4709 1.88977L 1.96274e-05 11.8658L 33.6047 60.6193L 48.2364 50.4825Z"
                      transform="translate(228.505 99.2263) scale(-1 1)"
                      fill="#E2197A"
                    />
                    <path
                      id="Vector_8"
                      d="M 26.4557 -1.96369e-05L -9.81598e-06 -1.96369e-05L -9.81598e-06 59.279L 26.4557 59.279L 26.4557 -1.96369e-05Z"
                      transform="matrix(-0.82281 -0.568375 -0.567825 0.82319 250.276 126.082)"
                      fill="white"
                    />
                    <path
                      id="Vector_9"
                      d="M 5.45783 -1.96415e-05L 0.0714335 20.0324C -0.250142 21.1587 0.553797 22.2046 1.67931 22.285L 22.3406 24.2963C 21.8582 19.5497 20.0091 14.5617 16.9542 10.0564C 13.7384 5.55113 9.71871 2.17217 5.45783 -1.96415e-05Z"
                      transform="translate(357.85 214.633) scale(-1 1)"
                      fill="#E2197A"
                    />
                    <path
                      id="Vector_10"
                      d="M 0 34.6746L 50.1658 0"
                      transform="translate(318.466 192.831) scale(-1 1)"
                      stroke="#F6F7F8"
                      strokeWidth="2"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                    <path
                      id="Vector_11"
                      d="M -1.96274e-05 31.3761L 45.3422 1.96415e-05"
                      transform="translate(311.552 154.938) scale(-1 1)"
                      stroke="#F6F7F8"
                      strokeWidth="2"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                    <path
                      id="Vector_12"
                      d="M 1.96274e-05 11.0219L 15.918 9.82073e-06"
                      transform="translate(335.429 191.785) scale(-1 1)"
                      stroke="#F6F7F8"
                      strokeWidth="2"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                  </g>
                  <g id="Group 5_4">
                    <path
                      id="Vector_13"
                      d="M 93.9124 87.2972C 99.3792 80.8611 102.193 75.149 103.881 68.9542C 105.328 64.2881 106.132 59.3001 106.293 54.0707C 106.775 24.7059 83.3808 0.490041 54.037 0.00733236C 24.6932 -0.475376 0.494662 22.936 0.0122985 52.3008C -0.228883 67.7475 2.90648 78.9302 24.1305 101.537C 37.8778 116.179 31.7679 124.788 32.0091 141.763C 32.0895 145.464 59.5038 147.394 60.147 143.935C 63.2019 127.201 58.3783 117.708 74.1355 105.399C 82.5768 98.8017 88.6868 93.1701 93.1888 88.1017C 93.43 87.8603 93.6712 87.619 93.9124 87.2972Z"
                      transform="translate(493.656 190.008) scale(-1 1)"
                      fill="#FFCCE5"
                    />
                    <path
                      id="Vector_14"
                      d="M 24.0144 111.466C 24.0144 111.466 24.0144 12.6721 5.52376 17.4187C -10.6354 21.5217 12.0357 66.4941 30.2047 62.6324C 51.0267 58.1271 50.062 -3.98141 34.7872 0.20207C 22.2457 3.66148 34.0636 74.0565 104.408 30.2105"
                      transform="translate(474.487 210.971) scale(-1 1)"
                      stroke="#E2197A"
                      strokeWidth="4"
                      strokeMiterlimit="10"
                      strokeLinecap="round"
                    />
                    <path
                      id="Vector_15"
                      d="M 24.7038 3.77687C 24.7842 2.16784 23.3371 0.880675 21.8096 1.12203C 13.931 2.1679 6.29358 0.800185 3.23862 0.0761214C 1.87192 -0.245684 0.505252 0.478359 0.103282 1.76558C -0.298687 3.21371 0.505242 4.66183 1.95233 4.98364C 3.96218 5.3859 3.88179 8.36266 3.96218 9.56943C 4.20336 13.592 7.90146 16.7296 12.0819 16.8101C 15.8605 16.8905 19.0762 14.4769 20.1213 11.0979C 20.2821 10.3739 20.7645 8.52352 21.0861 7.31675C 21.2469 6.75359 21.6488 6.35137 22.2116 6.35137C 23.5783 6.02957 24.6234 5.06409 24.7038 3.77687Z"
                      transform="translate(460.143 337.164) scale(-1 1)"
                      fill="#171A21"
                    />
                  </g>
                </g>
                <g id="Group 5_5">
                  <path
                    id="Vector_16"
                    d="M 53.8639 86.6462L 29.9869 49.6385L 62.4661 28.6407L 43.9755 3.92829e-05L -1.96274e-05 28.3993L 49.7638 105.633L 93.8197 77.2334L 86.3431 65.7288L 53.8639 86.6462Z"
                    transform="translate(315.17 323.403) scale(-1 1)"
                    fill="#EAA736"
                  />
                  <path
                    id="Vector_17"
                    d="M 44.0558 0L -9.81371e-06 28.3994L 18.4906 57.0401L 51.0501 36.1227L 74.8467 73.1304L 42.3676 94.1282L 49.8442 105.633L 93.8197 77.2334L 44.0558 0Z"
                    transform="translate(271.194 295.004) scale(-1 1)"
                    fill="#EAA736"
                  />
                  <path
                    id="Vector_18"
                    d="M 38.6776 0L -9.81577e-06 0L -9.81577e-06 44.0782L 38.6776 44.0782L 38.6776 0Z"
                    transform="matrix(-0.840223 -0.542274 -0.541726 0.840577 252.716 352.145)"
                    fill="#7A16FF"
                  />
                  <path
                    id="Vector_19"
                    d="M 177.043 129.617C 181.867 126.479 186.771 123.181 191.756 119.48L 249.88 79.6564L 232.596 52.7856C 232.596 52.7856 201.322 76.1969 180.581 83.1158C 164.261 87.5406 146.494 85.0466 142.153 70.9676C 137.65 56.5668 144.886 40.3961 142.394 33.7186C 139.901 26.9607 136.605 26.9606 130.656 22.3749C 125.029 18.111 124.546 13.123 120.848 14.5711C 117.713 15.7779 111.924 22.6967 118.034 34.7644C 123.421 45.384 128.244 69.3586 95.4437 68.5541C 82.5807 68.2323 65.1352 54.636 66.0999 43.5337C 67.0646 32.4314 81.7767 28.7306 86.0376 17.7892C 89.3337 9.3418 84.8317 0.331262 81.1336 0.00945601C 77.4355 -0.31235 72.0491 7.65232 59.6684 15.3757C 49.378 21.7313 41.4993 27.2825 41.9013 36.293C 42.866 54.636 71.3255 73.3008 70.0392 76.3579C 68.3509 80.3 50.5035 65.9796 38.6052 47.154C 29.8423 33.3163 21.9636 24.3057 18.5871 23.9839C 15.2105 23.6621 11.0301 33.3968 18.5067 48.6826C 30.0834 72.3353 53.6388 87.6211 51.0662 92.1264C 48.4936 96.6317 31.5305 80.4609 20.2754 66.6232C 10.2262 54.2337 4.03582 46.9126 0.980854 51.257C -0.868206 53.9119 -0.868225 63.4857 7.89471 75.2316C 16.6576 87.0579 42.7857 104.435 39.7307 107.251C 36.6758 110.067 17.542 92.0459 12.7183 91.3219C 8.45747 90.6782 3.39267 94.0571 13.4419 106.849C 22.2048 117.951 46.725 146.672 86.118 153.35C 117.632 158.74 145.288 150.051 177.043 129.617L 177.043 129.617Z"
                    transform="translate(547.604 298.937) scale(-1 1)"
                    fill="#7B16FF"
                  />
                  <path
                    id="Vector_20"
                    d="M 6.91534 13.8348C 10.7346 13.8348 13.8306 10.7377 13.8306 6.91733C 13.8306 3.09697 10.7346 -1.96373e-05 6.91534 -1.96373e-05C 3.09611 -1.96373e-05 -1.96315e-05 3.09697 -1.96315e-05 6.91733C -1.96315e-05 10.7377 3.09611 13.8348 6.91534 13.8348Z"
                    transform="matrix(-0.840223 -0.542274 -0.541726 0.840577 297.33 354.322)"
                    fill="#ACC7FF"
                  />
                  <path
                    id="Vector_21"
                    d="M 10.3593 64.8323L 73.5489 24.0435L 69.1273 17.2051C 57.8721 -0.252844 34.6383 -5.24085 17.1928 6.02235C -0.252703 17.2856 -5.23709 40.536 6.01805 57.994L 10.3593 64.8323Z"
                    transform="translate(313.068 278.925) scale(-1 1)"
                    fill="#ACC7FF"
                  />
                  <path
                    id="Vector_22"
                    d="M 7.42019 39.5256L 43.8386 16.0338L 39.8993 9.91947C 33.3874 -0.136962 19.9616 -3.03321 9.91238 3.48335C -0.136854 9.99992 -3.03103 23.4354 3.48087 33.4918L 7.42019 39.5256Z"
                    transform="translate(296.783 295.624) scale(-1 1)"
                    fill="#171A21"
                  />
                  <path
                    id="Union_2"
                    fillRule="evenodd"
                    clipRule="evenodd"
                    d="M 4.51709 13.3328C 2.60986 10.3733 3.46143 6.42773 6.4176 4.51978C 9.3739 2.61182 13.3168 3.46313 15.224 6.42236C 16.796 8.86157 16.4939 11.9707 14.6838 14.0566L 11.3196 8.85522C 10.7947 8.0437 9.71118 7.81128 8.89966 8.33618C 8.08813 8.86108 7.85571 9.94458 8.38062 10.7561L 11.7529 15.97C 9.09131 16.7949 6.10168 15.7913 4.51709 13.3328ZM 13.7007 18.9814C 9.36609 20.814 4.21375 19.323 1.57629 15.2307C -1.37756 10.6472 -0.0595703 4.53442 4.52161 1.57788C 9.10278 -1.37891 15.2109 -0.0588379 18.1648 4.52441C 20.788 8.59473 20.0422 13.8711 16.634 17.072L 27.3983 33.7148C 27.9232 34.5264 27.6908 35.6096 26.8793 36.1345C 26.0677 36.6594 24.9844 36.4272 24.4595 35.6155L 13.7007 18.9814Z"
                    transform="translate(317.704 258.247) scale(-1 1)"
                    fill="#EAA736"
                  />
                  <path
                    id="Vector_23"
                    d="M 8.12147 16.2477C 12.6068 16.2477 16.243 12.6106 16.243 8.12387C 16.243 3.63717 12.6068 0 8.12147 0C 3.6361 0 0 3.63717 0 8.12387C 0 12.6106 3.6361 16.2477 8.12147 16.2477Z"
                    transform="matrix(-0.840223 -0.542274 -0.541726 0.840577 304.684 320.094)"
                    fill="white"
                  />
                  <path
                    id="Vector_24"
                    d="M 8.12148 16.2478C 12.6069 16.2478 16.243 12.6106 16.243 8.12393C 16.243 3.63723 12.6069 9.81867e-06 8.12148 9.81867e-06C 3.63611 9.81867e-06 9.81577e-06 3.63723 9.81577e-06 8.12393C 9.81577e-06 12.6106 3.63611 16.2478 8.12148 16.2478Z"
                    transform="matrix(-0.840223 -0.542274 -0.541726 0.840577 286.831 308.584)"
                    fill="white"
                  />
                  <path
                    id="Vector_25"
                    d="M 0 5.63162C 0 5.63162 1.2059 0.965437 8.68253 1.96415e-05"
                    transform="translate(288.318 313.83) scale(-1 1)"
                    stroke="white"
                    strokeWidth="4"
                    strokeMiterlimit="10"
                  />
                  <path
                    id="Vector_26"
                    d="M 21.3848 -1.96415e-05C 27.2535 9.17145 27.2535 19.6301 21.3848 23.4113C 15.516 27.1926 5.94916 22.9286 9.81371e-06 13.7572L 21.3848 -1.96415e-05Z"
                    transform="translate(229.47 397.66) scale(-1 1)"
                    fill="#171A21"
                  />
                  <path
                    id="Vector_27"
                    d="M 172.445 1.80339C 127.264 -5.03499 86.9862 8.15907 50.407 31.49C 50.005 31.6509 49.6834 31.8118 49.2815 32.0532C 48.4775 32.6163 47.754 33.099 46.95 33.6622C 42.2068 36.7998 37.4636 40.0983 32.8007 43.5577C 15.516 55.7863 -1.96274e-05 66.7277 -1.96274e-05 66.7277L 17.2043 93.679L 51.3717 73.1638C 62.6268 66.4059 93.0158 49.5916 120.752 49.9938C 150.578 50.3961 180.163 70.5089 169.711 99.7933C 162.637 119.504 133.454 135.594 112.632 129.963C 91.5686 124.25 76.5349 113.309 76.4546 121.596C 76.3742 128.917 90.0412 138.651 97.8394 141.789C 107.647 145.731 109.496 147.099 94.0608 150.719C 66.4053 157.236 46.4677 170.43 46.0657 177.188C 45.6638 183.946 70.7466 168.579 83.5293 168.579C 89.6392 168.579 72.1134 172.039 56.0346 196.576C 48.8795 207.598 53.8639 208.966 65.6819 199.392C 82.4038 185.715 93.4177 176.705 96.6335 178.475C 99.8493 180.245 94.3021 182.98 88.6745 198.024C 79.2684 223.447 88.6745 225.861 97.4374 210.494C 106.2 195.048 118.581 180.164 122.118 181.934C 125.656 183.704 118.822 192.554 115.365 212.264C 113.677 222.16 116.812 237.043 125.495 213.391C 133.775 190.945 146.156 181.612 162.315 177.188C 223.817 160.293 239.172 135.836 247.854 112.183C 269.963 52.5683 225.103 9.76808 172.445 1.80339Z"
                    transform="translate(227.138 228.276) scale(-1 1)"
                    fill="#7B16FF"
                  />
                  <path
                    id="Vector_28"
                    d="M 6.27072 -1.96415e-05C 7.15506 1.68946 6.51189 3.86167 4.74322 4.74664C 3.05495 5.6316 0.884343 4.98797 9.81371e-06 3.21804"
                    transform="translate(296.599 320.829) scale(-1 1)"
                    stroke="#7415FC"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_29"
                    d="M 6.27073 3.92829e-05C 7.15507 1.68952 6.5119 3.86163 4.74323 4.7466C 3.05496 5.63156 0.884353 4.98803 1.96274e-05 3.2181"
                    transform="translate(278.751 309.324) scale(-1 1)"
                    stroke="#7415FC"
                    strokeWidth="2"
                    strokeMiterlimit="10"
                    strokeLinecap="round"
                  />
                  <path
                    id="Vector_30"
                    d="M 37.6244 43.0415L 47.0304 37.0077L 23.1535 0L -1.96274e-05 14.964C 3.53731 20.0324 15.8376 35.4791 37.6244 43.0415Z"
                    transform="translate(275.776 352.124) scale(-1 1)"
                    fill="white"
                  />
                  <path
                    id="Vector_31"
                    d="M 9.32569 0L 1.96274e-05 6.03386L 23.877 43.0415L 47.0304 28.158C 25.2437 20.5956 12.9434 5.14889 9.32569 0Z"
                    transform="translate(285.183 367.008) scale(-1 1)"
                    fill="#ACC7FF"
                  />
                </g>
              </g>
              <g id="Group 5_6">
                <path
                  id="Vector_32"
                  d="M 228.476 149.606C 234.689 141.939 239.515 132.885 240.239 123.106C 240.963 112.602 236.861 102.34 231.311 93.4066C 225.762 84.4727 218.704 76.565 212.672 67.9329C 211.104 65.6391 209.535 63.2245 209.174 60.5081C 208.51 55.3772 212.129 50.7895 215.085 46.5036C 220.695 38.4752 224.676 28.7566 223.47 19.0379C 220.755 -3.41754 196.204 -5.46994 183.296 10.0437C 176.902 17.7703 173.343 28.8773 175.514 38.777C 177.022 45.5982 180.762 51.7553 181.788 58.6972C 182.813 65.6391 179.435 74.0901 172.498 74.9955C 168.336 75.5388 164.234 73.0638 161.52 69.8042C 158.805 66.5445 157.116 62.6208 155.066 58.9386C 150.481 50.7291 143.303 43.4854 134.195 41.2519C 119.657 37.7508 104.939 48.1334 97.2781 61.0514C 93.3572 67.6311 90.7031 74.9351 86.7219 81.5148C 82.7407 88.0342 76.8896 94.0706 69.4098 95.7608C 66.5747 96.4248 63.4983 96.3644 60.9045 95.0364C 56.2598 92.6822 54.4502 86.9476 54.0883 81.7563C 53.7264 76.565 54.3296 71.1926 52.6406 66.3031C 48.1165 53.4455 31.2266 51.5742 19.8863 55.1357C 9.75233 58.335 -3.69927 68.4762 0.945449 80.4886C 4.92663 90.7506 17.8957 97.8735 27.9693 100.59C 29.4773 101.012 31.0457 101.797 31.5282 103.306C 32.0108 104.755 31.4076 106.324 30.4424 107.532C 27.9089 110.791 24.7119 113.447 25.6167 118.035C 26.4612 122.2 30.6837 125.581 34.9665 125.037C 40.2144 124.373 44.3766 122.019 45.8243 129.021C 48.4181 141.396 44.256 156.608 53.4851 165.18C 60.5426 171.759 72.3655 170.25 80.0866 164.516C 87.8077 158.781 92.5127 149.907 96.9765 141.396C 101.44 132.885 106.326 124.072 114.228 118.578C 117.003 116.707 121.105 115.379 123.397 117.854C 124.302 118.76 124.664 120.088 124.845 121.355C 126.353 131.677 116.701 141.034 117.848 151.417C 118.692 159.566 126.051 165.602 133.833 168.198C 141.554 170.793 149.878 170.854 157.961 172.242C 164.415 173.389 171.533 176.105 173.765 182.263C 175.756 187.756 173.102 193.732 170.99 199.165C 167.914 207.012 165.923 215.523 166.828 223.914C 167.733 232.305 171.895 240.635 179.013 245.162C 188.302 251.078 200.97 249.508 210.199 243.472C 219.428 237.435 225.641 227.777 230.105 217.696C 236.439 203.571 239.153 185.281 228.597 173.993C 225.219 170.431 220.393 167.172 220.393 162.222C 220.393 158.54 223.168 155.582 225.581 152.865C 226.606 151.839 227.571 150.753 228.476 149.606Z"
                  transform="translate(189.504 4.12622) scale(-1 1)"
                  fill="#1CD2F2"
                />
                <path
                  id="Vector_33"
                  d="M 50.3632 22.9232C 50.122 9.48785 38.7864 -3.5453 23.6724 0.879529C 8.31716 5.30436 -3.90271 20.8315 1.1621 37.2436C 5.82495 52.2076 23.5116 51.7248 34.8472 45.6105C 38.6257 43.5992 42.3238 41.1857 45.1376 37.8872C 48.9161 33.5428 50.524 28.1526 50.3632 22.9232Z"
                  transform="translate(113.903 208.674) scale(-1 1)"
                  fill="#1CD2F2"
                />
              </g>
            </g>
          </g>
        </g>
      </g>
    </InlineSvg>
  </SvgWrapper>
);
